
<nav class="top-bar" data-topbar role="navigation">
  <ul class="title-area">
    <li class="name">
      <h1> <!-- a href="#">Titel pagina</a --> </h1>
    </li>

    <li class="toggle-topbar menu-icon"><a href="#"><span>Menu</span></a></li>
  </ul>

  <section class="top-bar-section">
    <!-- Right Nav Section -->
    <ul class="right">
      <li><a href="#">Link 2 </a></li>
      <li class="has-dropdown">
        <a href="#">Link3 Dropdown</a>
        <ul class="dropdown">
          <li><a href="#">Link 1 dropdown</a></li>
          <li class="active"><a href="#">link 2 dropdown actief</a></li>
          <li><a href="#">Link 3 dropdown</a></li>
        </ul>
      </li>
    </ul>

    <!-- Left Nav Section -->
    <ul class="left">
      <li class="active"><a href="#">Home</a></li>
      <li><a href="#">Link 1</a></li>
    </ul>
  </section>
</nav>
