

<!-- nieuws + content-->

<div class="fl-block style-2">

        <h4 class="block-title "><a itemprop="url" href="#">Nieuws</a></h4>

          <div itemscope="" itemtype="http://schema.org/Article" class="field full news">
            <a itemprop="url" href="#">
                <h5 itemprop="name">Vlaamse overheid is werkgever van het jaar</h5>
                  <p itemprop="description">Lorem ipsum dolor sit amet, consectetur adipiscing elit. Cras leo lacus, ultrices in orci id, porttitor finibus metus. Pellentesque iaculis libero a erat tempor, id interdum lectus sodales. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas.</p>
            </a>
          </div>

          <div itemscope="" itemtype="http://schema.org/Article" class="field full news">
            <a itemprop="url" href="#">
                  <figure><img itemprop="image" src="https://inventaris.onroerenderfgoed.be/afbeeldingen/180002?size=small.png" width="150" alt="Alt descritpion" /></figure>
                  <h5 itemprop="name">De stemmen zijn geteld</h5>
                  <p itemprop="description">Lorem ipsum dolor sit amet, consectetur adipiscing elit. Cras leo lacus, ultrices in orci id, porttitor finibus metus. Pellentesque iaculis libero a erat tempor, id interdum lectus sodales. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas.</p>
            </a>
          </div>

          <div itemscope="" itemtype="http://schema.org/Article" class="field full news">
            <a itemprop="url" href="#">
                <h5 itemprop="name">Huurpremie na 4 jaar wachten op sociale woning</h5>
                  <p itemprop="description">Lorem ipsum dolor sit amet, consectetur adipiscing elit. Cras leo lacus, ultrices in orci id, porttitor finibus metus. Pellentesque iaculis libero a erat tempor, id interdum lectus sodales. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas.</p>
            </a>
          </div>

          <div itemscope="" itemtype="http://schema.org/Article" class="field full news">
            <a itemprop="url" href="#">
                  <figure><img itemprop="image" src="https://inventaris.onroerenderfgoed.be/afbeeldingen/180002?size=small.png" width="150" alt="Alt descritpion" /></figure>
                  <h5 itemprop="name">De stemmen zijn geteld</h5>
                  <p itemprop="description">Lorem ipsum dolor sit amet, consectetur adipiscing elit. Cras leo lacus, ultrices in orci id, porttitor finibus metus. Pellentesque iaculis libero a erat tempor, id interdum lectus sodales. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas.</p>
            </a>
          </div>

          <div itemscope="" itemtype="http://schema.org/Article" class="field full news">
            <a itemprop="url" href="#">
                <h5 itemprop="name">Huurpremie na 4 jaar wachten op sociale woning</h5>
                  <p itemprop="description">Lorem ipsum dolor sit amet, consectetur adipiscing elit. Cras leo lacus, ultrices in orci id, porttitor finibus metus. Pellentesque iaculis libero a erat tempor, id interdum lectus sodales. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas.</p>
            </a>
          </div>

          <div class="field"><a itemprop="url" class="more" href="#">toon alles  &rsaquo;</a></div>

</div>

<!-- end nieuws + content -->


