
<nav class="top-bar" data-topbar role="navigation">

  <ul class="title-area">
    <li class="name">
      <h1> <!-- a href="#">Title pagina</a --> </h1>
    </li>
    <li class="toggle-topbar menu-icon"><a href="#"><span>Menu</span></a></li>
  </ul>

  <section class="top-bar-section">

    <ul class="">
      <li class="active"><a href="#">Home</a></li>
      <li class=""><a href="#">Link2</a></li>
      <li class=""><a href="#">Link3</a></li>
      <li class="has-dropdown">
        <a href="#">Link 3 drop</a>
        <ul class="dropdown">
          <li class=""><a href="#">link 1 in dropdown</a></li>
          <li class=""><a href="#">link 2 in dropdown actief</a></li>
          <li class="active"><a href="#">link 3 in dropdown</a></li>
          <li class=""><a href="#">link 4 in dropdown</a></li>
        </ul>
      </li>
      <li class=""><a href="#">Link4</a></li>
      <li class=""><a href="#">Link5</a></li>
      <li class=""><a href="#">Link6</a></li>
    </ul>

  </section>

</nav>
