{% extends "inventaris-layout.jinja2" %}
{% block content %}



 
<!-- content -->


<div class="row">


  <div class="large-9 columns">
      
  <div class="panel">
      
<article class="" itemscope itemtype="http://schema.org/Article">
   
  <header>   
    <h1 itemprop="name">Dorpswoning met reclameschildering <small>(ID: 214860)</small></h1>
  </header>   


<br>

<div class="large-6 columns">
<figure class="bb-imagelarge"><a href=""><img src="https://inventaris.onroerenderfgoed.be/afbeeldingen/187263?size=full"></a></figure>
</div>


<div class="large-6 columns">
<ul class="clearing-thumbs small-block-grid-3" data-clearing>
    <li><a class="" role="button" aria-label="Thumbnail" href="path/to/your/img"><img data-caption="caption 2 here..." src="https://inventaris.onroerenderfgoed.be/afbeeldingen/187263?size=full"></a></li>
    <li><a class="" role="button" aria-label="Thumbnail" href="path/to/your/img"><img data-caption="caption 2 here..." src="https://inventaris.onroerenderfgoed.be/afbeeldingen/187263?size=full"></a></li>
    <li><a class="" role="button" aria-label="Thumbnail" href="path/to/your/img"><img data-caption="caption 2 here..." src="https://inventaris.onroerenderfgoed.be/afbeeldingen/187263?size=full"></a></li>
    <li><a class="" role="button" aria-label="Thumbnail" href="path/to/your/img"><img data-caption="caption 2 here..." src="https://inventaris.onroerenderfgoed.be/afbeeldingen/187263?size=full"></a></li>
</ul>
</div>
          

<div class="clearfix"></div>
<h3>Administratieve Gegevens</h3>



<table>


    <tr>
      <th>Alternatieve naam</th>
      <td></td>
    </tr>

    <tr>
      <th>Provincie</th>
      <td>Vlaams-Brabant</td>
    </tr>

    <tr>
      <th>Gemeente</th>
      <td>Londerzeel</td>
    </tr>

    <tr>
      <th>Deelgemeente</th>
      <td>Londerzeel</td>
    </tr>
    <tr>
      <th>Adres</th>
      <td>Stationsstraat 47</td>
    </tr>
    <tr>
      <th>Status</th><td>
      <a href="/dibe/relict/214860/locatie/adressen" title="Ga naar de uitgebreide adres- en statusinformatie voor dit relict."> Bewaard</a>
      </td>
    </tr>
    <tr>
    <th>Vastgesteld</th>
    <td>Ja</td>
    </tr>
    <tr>
    <th>Beschermingen</th>
    <td>
        <ul class="disk">
        <li><a href="https://beschermingen.onroerenderfgoed.be/object/id/4.01/23045/122.1/" target="_blank">4.01/23045/122.1</a></li>
        <li><a href="https://beschermingen.onroerenderfgoed.be/object/id/4.02/23045/106.1/" target="_blank">4.02/23045/106.1</a></li>
        </ul>
    </td>
    </tr>
    <tr>
    <th>Gebeurtenissen</th>
    <td>
    
    Aanvulling inventaris bouwkundig erfgoed 2012 (01-01-2012 - 31-12-2012).
    
    </td>
    </tr>
    <tr>
      <th>Verdere informatie</th>
      <td></td>
    </tr>
    </td>
    </tr>

</table>


<h3>Beknopte karakterisering</h3>

<table>
    <tr>
        <th>Typologie</th>
        <td><a href="/thesaurus/typologie/126">dorpswoningen</a></td></tr><tr>
        <th>Context</th>
        <td></td>
        </tr>
        <tr><th>Datering</th>
        <td><a href="/thesaurus/datering/1068">vóór WO I</a></td>
        </tr>
        <tr><th>Stijl</th>
        <td></td>
        </tr>
        <tr>
        <th>Trefwoorden</th>
        <td>Reclameschilderingen</td>
    </tr>
</table>


<h3>Beschrijving</h3>

    <p>Eenvoudige dorpswoning van vier traveeën en anderhalve bouwlaag onder zadeldak, kadastraal geregistreerd in 1912 als 'nouvelle construction' voor Karel Van der Straeten - Van Steen, 'verkensbeenhouwer'. Lijstgevel met karakteristieke gevelbekleding van wit geglazuurde baksteen uit het eerste kwart van de 20ste eeuw. Decoratieve accenten door de verwerking van groen geglazuurde baksteen. Rechthoekige vensters met vernieuwd schrijnwerk op hardstenen lekdrempels. Steekboogdeur.</p>

    <p>Het meest opvallende aan de woning is evenwel de reclameschildering op de rechtse zijgevel. Ze is van de hand van de amateurschilder Jan Stroobants en kreeg de benaming "Olijfje 1938" omdat het figuurtje duidelijk geïnspireerd is op Olive, het vriendinnetje van Popeye uit de tekenfilms. De bijhorende slagzin luidt "Kookt elektrisch". De opdrachtgever was ENB (Elektriciteit Noord België). Het was de bedoeling om met geschilderde muurreclame het gebruik van elektrische fornuizen te stimuleren. Het jaar 1938 verwijst naar het jaar dat elektrische fornuizen voor het eerst massaal werden geproduceerd. Onderaan rechts wordt een telefoonnummer aangehaald; op basis hiervan kon de schilder achterhaald worden. Naar verluidt zou de muurschildering in meerdere exemplaren hebben bestaan doch dit is het enig gekende, bewaarde exemplaar.</p>



Gegevens verstrekt door de heer E. Deschepper.<br>
Kadasterarchief Vlaams-Brabant, Londerzeel, 1ste afdeling, sectie C, mutatieschetsen 1912/18.
 

<div style="background:#efefef;height:319px;margin:30px 0">toon op kaart</div>

                
<section>
<ul class="source">
<li>Bron : -</li>
<li>Auteurs : <span class="author" itemprop="author" itemscope itemtype="http://schema.org/Person">Kennes, Hilde</span></li>
<li>Datum : <time itemprop="datePublished" datetime="2014-12-16">16 december 2014</time></li>
</ul>
</section>             
        
           

<hr>

<ul class="socialbox dropdown right clearfix">
    <li class="facebook"><a href="#"><i class="fa fa-facebook-square"></i> Facebook</a></li>
    <li class="twitter"><a href="#"><i class="fa fa-twitter"></i> Twitter</a></li>
    <li class="mail"><a href="#"><i class="fa fa-envelope"></i> Mailen</a></li>
    <li class="print"><a href="#"><i class="fa fa-print"></i> Printen</a></li>
</ul>


<hr>

<section>
<h4>Relaties</h4>
<ul class="disk">
<li><span>maakt deel uit van <a href="/dibe/geheel/21475">Londerzeel</a></span></li>
<li><span>maakt deel uit van <a href="/dibe/geheel/21475">Londerzeel</a></span></li>
<li><span>maakt deel uit van <a href="/dibe/geheel/21475">Londerzeel</a></span></li>
<li><span>maakt deel uit van <a href="/dibe/geheel/21475">Londerzeel</a></span></li>
</ul>
</section>  


</article>

      </div>

  </div>


<div class="large-3 columns">

{% include "includes/blokken/search-6.jinja2" %}
{% include "includes/blokken/nieuws-2.jinja2" %}
{% include "includes/blokken/social-1.jinja2" %}

</div>

</div>


<!-- end content -->




<!-- footer -->
{% include "pyoes/footer.jinja2" %}
<!-- end footer -->

 
  
{% endblock %}