{% extends "layout.jinja2" %}

{% set mailto_notfound = mailto_notfound|default('ict@onroerenderfgoed.be') -%}
{% set app_package = app_package|default('Pyoes') %}

{% block html_title %}Page not found | {{app_package}} | Onroerend Erfgoed{% endblock %}

{% block content %}
  <div class="large-12 columns" style="height:100%">
    <div class="text-center" style="padding:20px 0; color: #753F7F;">
      <h1 style="font-size:60px;">
        <i class="fa fa-warning"></i>
        <span>404</span><br>
      </h1>
      <h3><span>De pagina werd niet gevonden.</span></h3>
      <h4><strong><span style="color:#753F7F">De pagina die je hebt opgevraagd, bestaat niet (meer) of ze is verplaatst.</span></strong></h4>
    </div>
    <div class="row">
      <div class="large-12 columns">
        <div class="panel">
          <div class="text-center">
            <div class="small-10 small-centered columns" style="padding:20px 0">
              <h5 class="text-left">Wat kan je zelf doen?</h5>
              <ul class="disk text-left">
                <li><strong>Controleer de schrijfwijze van de URL.</strong>
                  De oorsprong van dit probleem kan een eenvoudige tikfout zijn.
                </li>
                <li><strong>Ben je foutief doorgelinkt?</strong>
                  Meld het ons via <a href="mailto:{{ mailto_notfound }}">{{ mailto_notfound }}</a>.
                </li>
                <li><strong>Werd de pagina gewist of verplaatst?</strong>
                  Dan kan je een nieuwe zoekopdracht starten op de
                  <a href="/">homepagina.</a>
                </li>
              </ul>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
{% endblock %}