
    <!-- article img -->




    <div class="row">
		<div class="large-12 columns">


		    <div itemscope="" itemtype="http://schema.org/Article" class="">

            <a itemprop="url" href="#">
                  <figure><img itemprop="image" src="https://inventaris.onroerenderfgoed.be/afbeeldingen/180002?size=small.png" width="150" alt="Alt descritpion" /></figure>

                  <h5 itemprop="name">De stemmen zijn geteld</h5>

                  <p itemprop="description">Lorem ipsum dolor sit amet, consectetur adipiscing elit. Cras leo lacus, ultrices in orci id, porttitor finibus metus. Pellentesque iaculis libero a erat tempor, id interdum lectus sodales. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas.</p>
            </a>
          </div>




    	</div>
    </div>

