
<!-- start promo -->

<div class="block-holder clearfix">

    <div class="fl-block style-3">
  		<a href="">
	        <div class="block-image field full"><img itemprop="image" src="https://encrypted-tbn1.gstatic.com/images?q=tbn:ANd9GcTm9hxNly_xBNbjxcbPhKGHvH2raxBfP5jBcRDtPnjl41ROEfJpVw" alt="" /></div>
	        <div class="block-date field">Onderwijs bepalend voor succes in volwassen leven</div>
	  	</a>
    </div>

</div>

<!-- end promo -->


