{% extends "layout.jinja2" %}

{% set active_main_nav = 'pinpoints' %}

{% set crumbs = [
	('Je bent hier:', '#', 'unavailable'), 
	('Home', '/', ''), 
	('Pinpoints', request.route_url('pinpoints'), 'current'),
]
-%}


{% set pinpoints = [
	'archeologietruweel', 'archeologievlag', 'boek', 'bouwkundig', 
	'heraldiek', 'info', 'landschap', 'maritiem', 
	'oorlog'
] %}

{% set kleuren = ['appelblauw-zeegroen', 'blauw', 'oranje', 'paars', 'geel', 'groen'] %}

{% block content %}
<div class="content">
	<div class="row">
		<h1>Formaten</h1>
		<div class="large-4 columns">
			<span class="pinpoint oorlog-paars"></span>
			<h4><small>oorlog-paars</small></h4>
		</div>
		<div class="large-4 columns">
			<span class="pinpoint oorlog-paars-half"></span>
			<h4><small>oorlog-paars-half</small></h4>
		</div>
		<div class="large-4 columns">
			<span class="pinpoint oorlog-paars-quarter"></span>
			<h4><small>oorlog-paars-quarter</small></h4>
		</div>
	</div>
	<div class="row">
		<h1>Pinpoints</h1>
	</div>
	{% for p in pinpoints %}
	<div class="row">
		<h2>{{ p }}</h2>
		{% for k in kleuren %} 
		<div class="large-4 columns">
			<span class="pinpoint {{ p }}-{{ k }}-quarter"></span>
			<h4><small>{{ p }}-{{ k }}</small></h4>
		</div>
		{% endfor %}
	</div>
	{% endfor %}
</div>
{% endblock %}
