
<!-- twitter -->


      <div class="fl-block style-twitter">

        <h4 class="block-title field"><a href="#">Nieuws Twitter</a></h4>

          <div class="field full rss">
             <a href="#">
                <time itemprop="datePublished" datetime="" class="posted">16u</time>
                <h5>Vlaamse overheid is werkgever van het jaar</h5>
            </a>
          </div>

      <div class="field full rss">
            <a href="#">
            <time itemprop="datePublished" datetime="" class="posted">16u</time>
            <h5>De stemmen zijn geteld</h5>
            </a>
      </div>

      <div class="field full rss">
          <a href="#">
          <time itemprop="datePublished" datetime="" class="posted">14u</time>
          <h5>Huurpremie na 4 jaar wachten op sociale woning</h5>
          </a>
      </div>

    <div class="field"><a class="more" href="#">toon alles  &rsaquo;</a></div>

    </div>