{% extends "layout.jinja2" %}
{% block content %}




<!-- content -->


<div class="row">
<div class="large-9 columns">
  <div class="panel">


    <article class="" itemscope itemtype="http://schema.org/Article">

        <h1>Erkende intergemeentelijke onroerenderfgoeddiensten</h1>

        <figure>
          <img itemprop="image" src="https://www.onroerenderfgoed.be/assets/files/made/assets/files/content/images/Oostkerke_Lettenburgstr_IMG_9062_832_370_s_c1.jpg" alt="">
            <figcaption>Maecenas ac tortor nec ligula facilisis commodo. Foto door <a href="#">Richard Clark</a></figcaption>
        </figure>

<section itemprop="articleBody">

<h4><em>Gemeenten kunnen de krachten bundelen en een intergemeentelijke onroerenderfgoeddienst (IOED) oprichten.</em></h4>

 <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. <strong>Cras leo lacus, ultrices in orci id, porttitor finibus metus</strong>. Pellentesque iaculis libero a erat tempor, id interdum lectus sodales. Pellentesque <a itemprop="url" href="" >habitant morbi tristique</a> senectus et netus et malesuada fames ac turpis egestas.</p>


<h2>Content</h2>

 <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Cras leo lacus, ultrices in orci id, porttitor fini bus metus. Pellentesque iaculis libero a erat tempor, id interdum lectus sodales. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas.</p>


<h3>Content</h3>

 <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Cras leo lacus, ultrices in orci id, porttitor fini bus metus. Pellentesque iaculis libero a erat tempor, id interdum lectus sodales. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas.</p>

<blockquote class="right">Lorem ipsum dolor sit amet, consectetur adipiscing elit. Cras leo lacus, ultrices in orci id, porttitor fini bus metus.<cite>Naam</cite></blockquote>

 <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Cras leo lacus, ultrices in orci id, porttitor fini bus metus. Pellentesque iaculis libero a erat tempor, id interdum lectus sodales. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Cras leo lacus, ultrices in orci id, porttitor fini bus metus. Pellentesque iaculis libero a erat tempor, id interdum lectus sodales. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas.</p>


<h5>Disk list item</h5>

<ul class="disk">
  <li><a href="">List item with a much longer description or more content.</a></li>
  <li><a href="">List item with a much longer description or more content.</a></li>
  <li>List item
    <ul>
  <li><span>List item</span></li>
  <li><span>List item</span></li>
  <li><span>List item</span></li>
    </ul>
  </li>
  <li><span>List item</span></li>
  <li><span>List item</span></li>
  <li><span>List item</span></li>
 </ul>

<hr>


<h5>NoDisk list item</h5>

<ul class="nodisk">
  <li><a href="">List item with a much longer description or more content.</a></li>
  <li>List <a href="">List item with a much longer description or more content.</a> item</li>
  <li>List item </li>
 </ul>

<hr>


<h5>Ordered list</h5>

<ol>
  <li>List item with a much longer <a href="">description</a> or more content.</li>
  <li>List item</li>
  <li>List item
    <ol>
      <li>Nested <a hre="">List Item</a></li>
      <li>Nested List Item</li>
      <li>Nested List Item</li>
    </ol>
  </li>
  <li>List item</li>
  <li>List item</li>
  <li>List item</li>
 </ol>

<h5>No numbers Ordered list</h5>

<ol class="nonumbers">
  <li>List item with a much longer <a href="">description</a> or more content.</li>
  <li>List item</li>
  <li>List item</li>
 </ol>

<dl>
  <dt>Definition Title</dt>
  <dd>Definition Cras justo odio, dapibus ac facilisis in, egestas eget quam. Nullam id dolor id nibh ultricies vehicula ut id elit.</dd>
</dl>


<hr>
{% include "includes/blokken/social-2.jinja2" %}
<hr>
{% include "includes/elements/form-2.jinja2" %}



<h4>280 reacties</h4>

<ul class="reactions">

<li>
  <cite>naam1</cite> - <span class="">12/01/15 14u34</span>
        <blockquote>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Praesent mattis euismod tincidunt. Fusce tempus ex nisi, a euismod dui elementum sit amet.
        </blockquote>
</li>

<li>
  <cite>naam2</cite> - <span class="">12/01/15 14u33</span>
        <blockquote>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Praesent mattis euismod tincidunt. Fusce tempus ex nisi, a euismod dui elementum sit amet.
        </blockquote>
</li>

<li>
  <cite>naam3</cite> - <span class="">12/01/15 14u34</span>
        <blockquote>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Praesent mattis euismod tincidunt. Fusce tempus ex nisi, a euismod dui elementum sit amet.
        </blockquote>
</li>

</ul>


</section>

</article>

      </div>

  </div>


<div class="large-3 columns">

{% include "includes/blokken/search-1.jinja2" %}
{% include "includes/blokken/downloads-1.jinja2" %}
{% include "includes/blokken/nieuws-3.jinja2" %}
{% include "includes/blokken/social-1.jinja2" %}


</div>


</div>


<!-- end content -->



<!-- footer -->
{% include "pyoes/footer.jinja2" %}
<!-- end footer -->



{% endblock %}