@charset "UTF-8";
//
// OE images CLASSES beeldbank
//

figure {margin:0 0 20px 0}
figcaption {margin:0 0 20px 0;/*border-bottom:1px solid $light-gray;*/padding:10px 0;font-size: $small-font-size;}


// beeldbank caption info detail image and tags

.caption-info dt {font-size:1em;padding:10px 0 0 0;}
.caption-info dd {margin:0;line-height:1.3em;}

.bb-imagelarge {margin:0 0 30px 0;padding:0}
.bb-imagelarge img {width:70%}

//new images
.bb-vertical-large {margin:0;padding:0}
.bb-horizontal-large {margin:0;padding:0}
.bb-horizontal-large img {width:60%}



// article place holder

aside img {margin:5px 20px 5px 0}

.figure-left  {float:left;margin:5px 20px 5px 0}
