
<!-- statistieken 1 -->


<div class="fl-block style-2">

  <h4 class="block-title field"><a href="#">Statistieken</a></h4>

    <div class="field ">

         <!-- circles -->

        <div class="circle">
            <div class="circle-inner">
                <div class="score-text">
                  <h3>82.057</h3>
                  <small>relicten bouwkundig <br>erfgoed</small>
                </div>
            </div>
        </div>

        <!-- end circles -->

     <a class="more" href="#">toon alles  &rsaquo;</a>

    </div>

</div>











