
    <!-- thumb -->

    <div class="row">
		<div class="large-12 columns">

		   	<ul class="clearing-thumbs small-block-grid-4" data-clearing>
				  <li><a class="th" role="button" aria-label="Thumbnail" href="https://inventaris.onroerenderfgoed.be/afbeeldingen/187263"><img data-caption="caption here..." src="https://inventaris.onroerenderfgoed.be/afbeeldingen/187263?size=medium.jpg"></a></li>
				  <li><a class="th" role="button" aria-label="Thumbnail" href="https://inventaris.onroerenderfgoed.be/afbeeldingen/200504"><img data-caption="caption 2 here..." src="https://inventaris.onroerenderfgoed.be/afbeeldingen/200504?size=small"></a></li>
				  <li><a class="th" role="button" aria-label="Thumbnail" href="https://inventaris.onroerenderfgoed.be/afbeeldingen/187263"><img data-caption="caption 3 here..." src="https://inventaris.onroerenderfgoed.be/afbeeldingen/187263?size=medium.jpg"></a></li>
			</ul>

    	</div>
    </div>

