<!doctype html>
<html class="no-js" lang="nl">

{% set app_package = app_package|default('pyoes', true) -%}
{% set active_title = active_title -%}

{% set service_nav = service_nav -%}
{% set main_nav = main_nav -%}
{% set dropdown_main_nav = dropdown_main_nav -%}
{% set active_main_nav = active_main_nav -%}
{% set login_nav = login_nav -%}
{% set login_sub_nav = login_sub_nav -%}
{% set home_link = home_link -%}
{% set header_links = header_links -%}
{% set mailto_error = mailto_error -%}
{% set plausible_data_domain = plausible_data_domain|default(request.registry.settings["plausible.data_domain"]) -%}
{% set plausible_omgeving = plausible_omgeving|default("dev") -%}
{% set burgerprofiel_header_id = burgerprofiel_header_id|default(request.registry.settings["burgerprofiel.header_id"]) -%}
{% set burgerprofiel_footer_id = burgerprofiel_footer_id|default(request.registry.settings["burgerprofiel.footer_id"]) -%}
{% set datum_copyright = datum_copyright|default('2025') -%}
{% set home_route = request.route_path('home') -%}

<head>
  {% block html_header scoped %}
    <!-- head -->
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{% block html_title %}Onroerend Erfgoed{% endblock %}</title>
    {% if plausible_omgeving in ('dev', 'test') %}
    <meta name="robots" content="noindex" />
    {% endif %}
    
    {% block css scoped -%}
      <!-- css -->
      {% set default_css_files = [
        request.static_path(app_package + ':static/css/app.css')
      ] -%}
      {% set css_files = css_files|default(default_css_files) -%}
      {% for css in css_files -%}
        <link rel="stylesheet" href="{{ css }}"/>
      {% endfor -%}
    {% endblock -%}
  {% endblock %}

  {% block plausible -%}
    {% if plausible_data_domain %}
      {% from 'macros.jinja2' import plausible_tracker %}
      {{ plausible_tracker(plausible_data_domain, plausible_omgeving) }}
    {% endif %}
  {% endblock %}
</head>
<body>
<div class="container">
  {% block vlaanderen_header scoped %}
    {% if burgerprofiel_header_id %}
      <div class="vlaanderen-header-container">
      	{% from 'macros.jinja2' import render_vlaanderen_header %}
        {{ render_vlaanderen_header(plausible_omgeving, burgerprofiel_header_id, request.authenticated_userid, home_route) }}
      </div>
    {% else %}
      <script src="//widgets.vlaanderen.be/widget/live/37de485347434fbdaa70e0c03eb48d01"></script>
    {% endif %}
    {% block constom_contact_info scoped %}
    {% endblock %}
  {% endblock %}

  {% block header scoped %}
    {% include "pyoes/header.jinja2" %}
  {% endblock %}

  {% block messages scoped %}
  {% endblock %}

  {% block content scoped %}
  {% endblock %}

  <div class="push"></div>

  <div id="footerContainer">
    {% block vlaanderen_footer scoped %}
      {% if burgerprofiel_header_id %}
          {% from 'macros.jinja2' import render_vlaanderen_footer %}
          {{ render_vlaanderen_footer(plausible_omgeving, burgerprofiel_footer_id) }}
      {% else %}
        <script src="//widgets.vlaanderen.be/widget/live/d619177b83734bf7b5bb596ff7e6c41e"></script>
      {% endif %}
    {% endblock %}

    {% block footer scoped %}
      <!-- Backwards compatible -->
    {% endblock %}
  </div>
</div>


{% block javascript scoped -%}
  <!-- javascript -->
  <!-- deze moet moet onderaan de pagina zitten om foundation goed te laten werken -->
  {% set default_js_files = [
    request.static_path(app_package + ':static/node_modules/foundation-sites/js/vendor/modernizr.js'),
    request.static_path(app_package + ':static/node_modules/foundation-sites/js/vendor/jquery.js'),
    request.static_path(app_package + ':static/node_modules/foundation-sites/js/foundation.min.js'),
    request.static_path(app_package + ':static/js/app.js')
  ] -%}
  {% set js_files = js_files|default(default_js_files) -%}
  {% for js in js_files -%}
    <script src="{{ js }}"></script>
  {% endfor -%}
{% endblock -%}

{% if request.registry.settings['pyoes.banner'] %}
  {% from 'macros.jinja2' import render_info_banner %}
  {{ render_info_banner(request.registry.settings['pyoes.banner'], request.registry.settings['pyoes.banner.detail']) }}
{% endif %}

</body>
</html>
