
<section>
<h4>List title</h4>
<ul class="disk">
<li><span>content <a href="/">link</a> content</span></li>
<li><span>content <a href="/">link</a></span></li>
<li><span><a href="/">link</a></span></li>
</ul>
</section>