
<!-- search 2 -->

    <div class="panel fl-block-search">

			<form name="" action="#" method="post" class="clearfix">
			<div class="searchBox">
			    <input type='text' placeholder='zoek' />
			    <button>zoeken</button>
			    <small><a href="">Uitgebreid zoeken</a> &rsaquo;</small>
			</div>
			</form>

    </div>

<!-- end search 2 -->

