
<form class="clearfix">

<h5>Reacties (0)</h5>

<h6>Reageer op dit artikel</h6>


      <div class="row">
        <div class="small-2 columns">
          <label for="label1" class="left inline">Naam</label>
        </div>

        <div class="small-10 columns">
          <input type="text" id="label1" placeholder="naam">
        </div>
      </div>


      <div class="row">
        <div class="small-2 columns">
          <label for="label2" class="left inline">Email adres</label>
        </div>

        <div class="small-10 columns">
          <input type="text" id="label2" placeholder="email">
        </div>
      </div>

      <div class="row">
        <div class="small-2 columns">
          <label for="label2" class="left inline">Reactie</label>
        </div>

        <div class="small-10 columns">
          <textarea placeholder="omschrijving"></textarea>
        </div>
      </div>

  


<a href="#" class="button right [tiny small large]">Plaats reactie</a>

</form>
