
<section>
<ul class="source">
<li>Bron : -</li>
<li>Auteurs : <span class="author" itemprop="author" itemscope itemtype="http://schema.org/Person">Kennes, Hilde</span></li>
<li>Datum : <time itemprop="datePublished" datetime="2014-12-16">16 december 2014</time></li>
</ul>
</section>   