


<!-- evenementen -->

    <div itemscope="" itemtype="http://schema.org/Article" class="fl-block style-2">

            <h4 itemprop="name" class="block-title field">Evenementen</h4>
            <div class="field full event"><a itemprop="url" href="#"><h5 itemprop="name">14 oktober 2013</h5><p> Ronde van Vlaanderen voor directies uit het secundair onderwijs</p></a></div>
            <div class="field full event"><a itemprop="url" href="#"><h5 itemprop="name">14 oktober 2013</h5><p> Ronde van Vlaanderen voor directies uit het secundair onderwijs</p></a></div>
            <div class="field full event"><a itemprop="url" href="#"><h5 itemprop="name">14 oktober 2013</h5><p> Ronde van Vlaanderen voor directies uit het secundair onderwijs</p></a></div>
            <div class="field full event"><a itemprop="url" href="#"><h5 itemprop="name">14 oktober 2013</h5><p> Ronde van Vlaanderen voor directies uit het secundair onderwijs</p></a></div>

    </div>

<!-- end evenementen-->


