{% extends "pyoes/layout.jinja2" %}
{% set service_nav =  [
    ('styleguide', 'Styleguide', '/')
    ]
%}
{% set active_title="Beeldbank" %}
{% set main_nav = [
    ('home', 'Home', 'beeldbank'), 
    ('detailpagina', 'Detailpagina', 'beeldbank-detail'), 
]-%}