{% extends "layout.jinja2" %}

{% set burgerprofiel_header_id = "305cb64e-aa12-4c3a-9cb9-a8a3686c1f59" -%}
{% set burgerprofiel_footer_id = "c98ebf58-109a-4ea9-966e-1accf1256515" -%}

{% set active_main_nav = 'burgerprofiel2' %}
{% block constom_contact_info %}
  {% from 'pyoes/macros.jinja2' import render_custom_burgerprofiel_contact %}
  {{ render_custom_burgerprofiel_contact() }}
  <script>
    render_contact({
      "displayMode": "grouped",
      "groupLabel": "Heb je een vraag of opmerking over een beeld in de beeldbank?",
      "contextual": [
        {
          "type": "link",
          "href": "{{ home_route }}contact",
          "label": "Stel je vraag via ons contactformulier"
        }
      ],
      "defaults": [
        {
          "type": "contactOption",
          "contactGroupId": "OVO000104",
        }
      ]
    })
  </script>
{% endblock %}

{% block content %}
  <!-- content -->
  <div class="row">
    <div class="large-12 columns">
      <div class="panel">
        test met burgerprofiel met aangepaste contact info blok
      </div>
    </div>
  </div>
  <!-- end content -->
{% endblock %}
