{% extends "inventaris-layout.jinja2" %}
{% block content %}



<!-- content -->


<div class="row">

<div class="large-8 columns">

<div class="panel">

<article class="" itemscope itemtype="http://schema.org/Article">

<h1>Vastgestelde inventaris van het Bouwkundig Erfgoed</h1>

<p>De vaststelling van de inventaris van het bouwkundig erfgoed bepaalt éénduidig in een overzichtelijke lijst per gemeente het gebouwd patrimonium van Vlaanderen. Aangezien de visie op onroerend erfgoed doorheen de jaren evolueert en het patrimonium in Vlaanderen onderhevig is aan veranderingen zoals verbouwingen, sloop en adreswijzigingen, is regelmatige actualisatie van de vastgestelde inventarisgegevens aangewezen. Op 28 november 2013 is een geactualiseerde lijst van de inventaris vastgesteld. Deze werd rechtsgeldig op 14 december 2013, 10 dagen na de publicatie in het Belgisch Staatsblad van 4 december.
</p>


<h5>Overzicht</h5>

<ul class="disk">

<li><a href="/dibe/rechtsgevolgen#f_vast_2013">Vaststelling van de  inventaris van het Bouwkundig Erfgoed op 28 november 2013</a></li>
<li><a href="/dibe/rechtsgevolgen#f_jur_kader">Juridisch kader</a></li>
<li><a href="/dibe/rechtsgevolgen#f_leeswijzer">Leeswijzer vastgestelde inventaris</a></li>
<li><a href="/dibe/rechtsgevolgen#f_rechtsgevolgen">Rechtsgevolgen van de vastgestelde inventaris</a></li>
<li><a href="/dibe/rechtsgevolgen#f_rechtsmiddelen">Rechtsmiddelen tegen opname in de vastgestelde inventaris </a></li>
<li><a href="/dibe/rechtsgevolgen#f_archief">Archief</a></li>
<li><a href="/faq">Veelgestelde vragen</a></li>
</ul>


<h2>Vaststelling van de  inventaris van het Bouwkundig Erfgoed op 28 november 2013</h2>
<div data-alert class="alert-box custom">

<h3><a href="/bestanden/vaststelling/vaststelling_28_11_2013.pdf" title="Download hier het PDF-bestand van de vaststelling, grootte 8.6MB">Besluit van de administrateur-generaal van 28 november 2013 houdende vaststelling van de inventaris van het bouwkundig erfgoed en vastgestelde lijst.</a></h3>

<ul class="disk">
<li>Belgisch staatsblad: 04/12/2013</li>
<li>Formaat en grootte: PDF, 8.6MB</li>
<li>MD5: fcc7bf55aff54fd2d5a6608e0667fea0</li>
<li>SHA256: 356f0704e903f33b0ecbb701129f897c1ebd9ad2788be2f1f4abecd87394d430</li>
</ul>

</div>


<h3>Juridisch kader</h3>
<p><strong>Decreet van 3 maart 1976 tot bescherming van monumenten, stads- en dorpsgezichten, art. 12/1.</strong><br>
De Vlaamse Regering stelt een inventaris van het bouwkundig erfgoed vast onder de vorm van een systematische oplijsting per gemeente, waarbij per opgenomen constructie of gezicht een beknopte wetenschappelijke beschrijving wordt gevoegd.<br>
De inventaris wordt beschikbaar gesteld in boekvorm of in een beveiligd gedigitaliseerd bestand.</p>

<p><a href="/dibe/rechtsgevolgen#f_inhoud">Terug naar het overzicht</a></p>

<hr>

<h3 id="">Archief</h3>

<ul class="disk">

<li>
<strong>2014</strong>
<br>
<a href="/bestanden/vaststelling/vaststelling_28_11_2014.pdf" title="Download hier het PDF-bestand van de vaststelling, grootte 8.3MB">Besluit van de administrateur-generaal van 28 november 2014 houdende vaststelling van de inventaris van het bouwkundig erfgoed en vastgestelde lijst.</a>

    <ul class="source">
    <li><span>Belgisch staatsblad: 01/12/2014</span></li>
    <li><span>Formaat en grootte: PDF, 8.3MB</span></li>
    <li><span>MD5: 9d2b03f21aa6b9f9a65b8456792975f4</span></li>
    <li><span>SHA256: 9412887d8cac3a943575e3439f328315327fb4f9588c42b5668244bf12482e95</span></li>
    </ul>

<hr>
</li>


<li>
<strong>2013</strong>
<br>
<a href="/bestanden/vaststelling/vaststelling_28_11_2013.pdf" title="Download hier het PDF-bestand van de vaststelling, grootte 8.5MB">Besluit van de administrateur-generaal van 28 november 2013 houdende vaststelling van de inventaris van het bouwkundig erfgoed en vastgestelde lijst.</a>

    <ul class="source">
    <li><span>Belgisch staatsblad: 04/12/2013</span></li>
    <li><span>Formaat en grootte: PDF, 8.6MB</span></li>
    <li><span>MD5: fcc7bf55aff54fd2d5a6608e0667fea0</span></li>
    <li><span>SHA256: 356f0704e903f33b0ecbb701129f897c1ebd9ad2788be2f1f4abecd87394d430</span></li>
    </ul>

</li>

</ul>


</article>

</div>

</div>


<div class="large-4 columns">

<!-- search 5 -->

<div class="large-12 ">

<div class="panel fl-block-search">

<form name="" action="#" method="post" class="clearfix">

  <input type='text' placeholder='zoek een ID' />
  <a href="#" class="button [tiny small large] right">ZOEKEN</a>

  <fieldset class="fl-block-search_fieldset">
     <select>
       <option value="">filter op</option>
       <option value="">1</option>
       <option value="">2</option>
       <option value="">3</option>
       <option value="">4</option>
     </select>
  </fieldset>

</form>

  <h5>Zoek een ...</h5>
 <ul class="disk">
        <li><a href="/dibe/relict/zoeken" title="Zoeken naar gebouwen, beelden, waterpompen, ...">bouwkundig relict</a></li>
        <li><a href="/dibe/gehelen/zoeken" title="Zoeken naar straten, gemeentes, plaatsen, begijnhoven, ...">(bouwkundig) geheel</a></li>
        <li><a href="/ile/park/zoeken" title="Zoeken naar tuinen en parken">tuin of park</a></li>
        <li><a href="/ile/boom/zoeken" title="Zoeken naar bomen, struiken, boomgaarden, bossen, ...">boom of struik</a></li>
        <li><a href="/ivm/varend/zoeken" title="Zoeken naar varend erfgoed">vaartuig</a></li>
        <li><a href="/woi/relict/zoeken" title="Zoeken naar bunkers, loopgraven, gedenktekens, ...">oorlogsrelict</a></li>
        <li><a href="/dibe/orgels/zoeken" title="Zoeken naar orgels met erfgoedwaarde">orgel</a></li>
        <li><a href="/dibe/personen/zoeken" title="Zoeken naar (tuin)architecten, bouwmeesters, orgelbouwers, ...">persoon of collectief</a></li>
    </ul>




    </div>
</div>

<!-- end search 5 -->


{% include "includes/blokken/downloads-1.jinja2" %}
{% include "includes/blokken/nieuws-3.jinja2" %}
{% include "includes/blokken/social-1.jinja2" %}



  </div>

</div>


<!-- end content -->




<!-- footer -->
{% include "pyoes/footer.jinja2" %}
<!-- end footer -->



{% endblock %}