{% extends "beeldbank-layout.jinja2" %}
{% block content %}



<!-- search -->
<div class="row">
{% include "includes/blokken/search-3ext.jinja2" %}
</div>
<!-- end search -->


<!-- content -->
<div class="row">
  <div class="large-12 columns">
    <div class="panel">

       content

    </div>
  </div>
</div>
<!-- end content -->



{% endblock %}