{% extends "layout.jinja2" %}

{% set mailto_notfound = mailto_notfound|default('ict@onroerenderfgoed.be') -%}
{% set app_package = app_package|default('Pyoes') %}

{% block html_title %}Failed Authentication | {{app_package}} | Onroerend Erfgoed{% endblock %}

{% block content %}
<div class="" style="height:100%">
	<div class="text-center" style="padding:20px 0; color: #753F7F;">
		<h1 style="font-size:60px;">
			<i class="fa fa-warning"></i>
			<span>401</span><br>
		</h1>
		<h3><span>Paswoord vereist.</span></h3>
		<h4><strong><span style="color: #753F7F;">Je kan deze pagina alleen maar bekijken als je beschikt over een paswoord. Heb je net geprobeerd om in te loggen? Dan was je login om de een of andere reden ongeldig.</span></strong></h4>
	</div>
	<div class="row">
		<div class="large-12 columns">
			<div class="panel">
				<div class="text-center">
					<div class="small-10 small-centered columns" style="padding:20px 0">
						<h5 class="text-left" style="">Wat kan je zelf doen?</h5>
						<ul class="disk text-left" style="margin-bottom:10px;">
							<li><strong>Controleer je logingegevens</strong></li>
						</ul>
					</div>
				</div>
			</div>
		</div>
	</div>
</div>
{% endblock %}