

<!-- search 1 -->

<div class="large-12 ">
    <div class="panel fl-block-search">

<form name="" action="#" method="post" class="clearfix">

  <input type='text' placeholder='zoek' />
  <a href="#" class="button [tiny small large] right">ZOEKEN</a>

  <fieldset class="fl-block-search_fieldset">
      <input id="checkbox1" type="checkbox"><label for="checkbox1">zoek binnen deze website</label><br>
      <input id="checkbox2" type="checkbox"><label for="checkbox2">zoek binnen Vlaanderen.be</label>
  </fieldset>

</form>

    </div>
</div>

<!-- end search 1-->




