

<!-- search 6 -->

<div class="large-12 ">

<div class="panel fl-block-search">

<form name="" action="#" method="post" class="clearfix">

  <input type='text' placeholder='zoek een ID' />
  <a href="#" class="button [tiny small large] right">ZOEKEN</a>

  <fieldset class="fl-block-search_fieldset">
     <select>
       <option value="">filter op</option>
       <option value="">1</option>
       <option value="">2</option>
       <option value="">3</option>
       <option value="">4</option>
     </select>
  </fieldset>

</form>

  <h5>Zoek een ...</h5>
 <ul class="disk">
        <li><a href="/dibe/relict/zoeken" title="Zoeken naar gebouwen, beelden, waterpompen, ...">bouwkundig relict</a></li>
        <li><a href="/dibe/gehelen/zoeken" title="Zoeken naar straten, gemeentes, plaatsen, begijnhoven, ...">(bouwkundig) geheel</a></li>
        <li><a href="/ile/park/zoeken" title="Zoeken naar tuinen en parken">tuin of park</a></li>
        <li><a href="/ile/boom/zoeken" title="Zoeken naar bomen, struiken, boomgaarden, bossen, ...">boom of struik</a></li>
        <li><a href="/ivm/varend/zoeken" title="Zoeken naar varend erfgoed">vaartuig</a></li>
        <li><a href="/woi/relict/zoeken" title="Zoeken naar bunkers, loopgraven, gedenktekens, ...">oorlogsrelict</a></li>
        <li><a href="/dibe/orgels/zoeken" title="Zoeken naar orgels met erfgoedwaarde">orgel</a></li>
        <li><a href="/dibe/personen/zoeken" title="Zoeken naar (tuin)architecten, bouwmeesters, orgelbouwers, ...">persoon of collectief</a></li>
    </ul>

    </div>
</div>

<!-- end search 6 -->




