{% extends "beeldbank-layout.jinja2" %}

{% block content %}

<!-- search -->

<div class="row">

  <div class="large-12 columns">
      
        {% include "beeldbank/beeldbank-zoeken.jinja2" %}

 <div class="row ">
    
  <div class="large-8 medium-8 columns">
    <h5>Er zijn geen resultaten beschikbaar</h5>
  </div>     

  <div class="large-4 medium-4 columns">       
  <select>
      <option value="">sorteer op</option>
      <option value="">datum/aflopend</option>
      <option value="">datum/aflopend</option>
      <option value="">datum/oplopend</option>
  </select>            
  </div>

  </div>


</form> 


        </div>
      </div>

</div>

<!-- end search -->



 
    <div class="row">

      <div class="large-12 columns">


        <div class="panel">


        <h1>Heading 1</h1>
        <h2>Heading 2</h2>
        <h3>Heading 3</h3>
        <h4>Heading 4</h4>
        <h5>Heading 5</h5>
        <h6>Heading 6</h6>
       
  
        <h1>Heading 1</h1>
   
        <article>
        Maecenas ac tortor nec <strong>ligula facilisis commodo</strong>. Etiam cursus augue ac interdum lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Suspendisse libero magna, volutpat vel massa sed, mollis hendrerit nisi. Quisque non augue a nisi auctor molestie ac sed turpis. Phasellus pulvinar, orci nec condimentum fringilla, mi arcu iaculis metus.
        </article>
        
      
        
        <h2>Heading 2</h2>

       <p>
        <b>Maecenas ac tortor nec ligula facilisis commodo</b>. Etiam cursus augue ac interdum lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Suspendisse libero magna, volutpat vel massa sed, mollis hendrerit nisi. Quisque non augue a nisi auctor molestie ac sed turpis. Phasellus pulvinar, orci nec condimentum fringilla, mi arcu iaculis metus.
        </p>


        <h3>Heading 3</h3>

        <p>
        Maecenas ac tortor nec ligula facilisis commodo. Etiam cursus augue ac interdum lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Suspendisse libero magna, volutpat vel massa sed, mollis hendrerit nisi. Quisque non augue a nisi auctor molestie ac sed turpis. Phasellus pulvinar, orci nec condimentum fringilla, mi arcu iaculis metus.
        </p>

        <h4>Heading 4</h4>
        <p>
        Maecenas ac tortor nec ligula facilisis commodo. Etiam cursus augue ac interdum lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Suspendisse libero magna, volutpat vel massa sed, mollis hendrerit nisi. Quisque non augue a nisi auctor molestie ac sed turpis. Phasellus pulvinar, orci nec condimentum fringilla, mi arcu iaculis metus.
        </p>

        <h5>Heading 5</h5>
        <p>
        Maecenas ac tortor nec ligula facilisis commodo. Etiam cursus augue ac interdum lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Suspendisse libero magna, volutpat vel massa sed, mollis hendrerit nisi. Quisque non augue a nisi auctor molestie ac sed turpis. Phasellus pulvinar, orci nec condimentum fringilla, mi arcu iaculis metus.
        </p>

        <h6>Heading 6</h6>
        <p>
        Maecenas ac tortor nec ligula facilisis commodo. Etiam cursus augue ac interdum lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Suspendisse libero magna, volutpat vel massa sed, mollis hendrerit nisi. Quisque non augue a nisi auctor molestie ac sed turpis. Phasellus pulvinar, orci nec condimentum fringilla, mi arcu iaculis metus.
        </p>






<hr>








        Maecenas ac tortor nec ligula facilisis commodo. Etiam cursus augue ac:

        <ul>
          <li>massa sed, mollis hendrerit nisi</li>
          <li>libero magna, volutpat vel massa sed</li>
        </ul> 
        

     
      </div>

   

       </div>
        </div>


     


    </div>

{% endblock %}
