{% extends "layout.jinja2" %}

{% block content %}


<!-- pagination -->
    <div class="pagination-centered">
      <ul class="pagination">
        <li class="arrow unavailable"><a href=""> &lsaquo; vorige</a></li>
        <li class=""><a href="">lijstscherm</a></li>
        <li class="arrow"><a href="">volgende  &rsaquo;</a></li>
      </ul>
    </div>
<!-- end pagination -->




    <div class="row">
      <div class="large-12 columns">

        <div class="panel">
        <header>
            <i class="fa fa-building actoren-icon-large"></i></a>
            <h1 style="margin:0">Onroerend erfgoed</h1>
            <h3><small>ID : 1</small></h3>
        </header>

            <div class="row">

              <div class="large-9 medium-9 columns">

                  <table class="table">

                    <tbody>
                      <tr>
                        <td style="width:150px">Afkorting</td>
                        <td> - </td>
                      </tr>

                      <tr>
                        <td>Actortype</td>
                        <td>bedrijf</td>
                      </tr>

                      <tr>
                        <td>Telefoon</td>
                        <td>02/553.16.50</td>
                      </tr>

                      <tr>
                        <td>Fax</td>
                        <td>02/553.16.55</td>
                      </tr>

                      <tr>
                        <td>Email werk</td>
                        <td><a href="mailto:info@vioe.be">info@vioe.be</a></td>
                      </tr>

                      <tr>
                        <td>URL website</td>
                        <td><a href="http://www.onroerenderfgoed.be/" target="blank">http://www.onroerenderfgoed.be/</a></td>
                      </tr>

                      <tr>
                        <td>Adres</td>
                        <td> - </td>
                      </tr>

                      <tr>
                        <td>Opmerkingen</td>
                        <td> - </td>
                      </tr>
                </table>

                <ul class="source-authors">
                    <li>Huidige status : Klad</li>
                    <li>Laatst gewijzigd door : Taeymma op 2015-03-11 om 13:25:45.734485.</li>
                    <li>Aangemaakt door : Anoniem op 2007-10-05 om 00:14:12</li>
                    <li>Laatst bewerkt door : <span class="author" itemprop="author" itemscope itemtype="http://schema.org/Person">Vandaeko</span> op
                    <time itemprop="datePublished" datetime="2009-05-06">2009-05-06 om 23:29:32</time></li>
                </ul>

              </div>

<div class="large-3 medium-3 columns">

    <h6 style="margin-top:12px">Relaties</h6>

  <div class="source-authors-block">

<ul class="source-authors-list nodisk">
<li><i class="fa fa-user"></i> <a href="">Van Daele, Koen</a> <small>ID : 1</small></li>
<li><i class="fa fa-user"></i> <a href="">Meylemans, Erwin</a></li>
<li><i class="fa fa-user"></i> <a href="">Cousserier, Katrien</a></li>
<li><i class="fa fa-user"></i> <a href="">Jansen, Isabelle </a></li>
<li><i class="fa fa-user"></i> <a href="">Hooft, Elise </a></li>
<li><i class="fa fa-user"></i> <a href="">Cherretté, Veerle </a></li>
<li><i class="fa fa-user"></i> <a href="">Kennes, Hilde </a></li>
<li><i class="fa fa-user"></i> <a href="">Driessen, Carolien </a></li>
<li><i class="fa fa-user"></i> <a href="">De Schutter, Maria </a></li>
<li><i class="fa fa-user"></i> <a href="">Jacobs, Bernadette </a></li>
<li><i class="fa fa-user"></i> <a href="">Michiels, Marijke </a></li>
<li><i class="fa fa-user"></i> <a href="">Buyle, Marianne </a></li>
<li><i class="fa fa-user"></i> <a href="">De Bodt, Vicky </a></li>
<li><i class="fa fa-user"></i> <a href="">Verwinnen, Katrien </a></li>
<li><i class="fa fa-user"></i> <a href="">Moeykens, Sofie </a></li>
<li><i class="fa fa-user"></i> <a href="">Braeken, Jo </a></li>
<li><i class="fa fa-user"></i> <a href="">Bergmans, Anna </a></li>
<li><i class="fa fa-user"></i> <a href="">Vynckier, Geert </a></li>
<li><i class="fa fa-user"></i> <a href="">Brees, Joris </a></li>
<li><i class="fa fa-user"></i> <a href="">Vanderhispallie, Eelkje </a></li>
<li><i class="fa fa-user"></i> <a href="">Meganck, Leen </a></li>
<li><i class="fa fa-user"></i> <a href="">Debonne, Vincent </a></li>
<li><i class="fa fa-user"></i> <a href="">Denis, Hans </a></li>
<li><i class="fa fa-user"></i> <a href="">Lo, Eva </a></li>
<li><i class="fa fa-user"></i> <a href="">Roose, Patrick </a></li>
<li><i class="fa fa-user"></i> <a href="">Heyn, Moira </a></li>
<li><i class="fa fa-user"></i> <a href="">Verhulst, Maryline </a></li>
<li><i class="fa fa-user"></i> <a href="">Vandesande, Aziliz </a></li>
<li><i class="fa fa-user"></i> <a href="">Ameels, Vera </a></li>
<li><i class="fa fa-user"></i> <a href="">Thomas, Hans </a></li>
<li><i class="fa fa-user"></i> <a href="">Daveloose, Barbara </a></li>
<li><i class="fa fa-user"></i> <a href="">De Haan, Aukje </a></li>
<li><i class="fa fa-user"></i> <a href="">Verboven, Hilde </a></li>
<li><i class="fa fa-user"></i> <a href="">Pieters, Marnix </a></li>
<li><i class="fa fa-user"></i> <a href="">Haneca, Kristof </a></li>
<li><i class="fa fa-user"></i> <a href="">Smets, Koen </a></li>
<li><i class="fa fa-user"></i> <a href="">Bartels, Walter </a></li>
<li><i class="fa fa-user"></i> <a href="">Buijs, Joke </a></li>
<li><i class="fa fa-user"></i> <a href="">Deforce, Koen </a></li>
<li><i class="fa fa-user"></i> <a href="">Hulstaert, Willem </a></li>
<li><i class="fa fa-user"></i> <a href="">van den Bossche, Herman </a></li>
<li><i class="fa fa-user"></i> <a href="">Verdurmen, Inge </a></li>
<li><i class="fa fa-user"></i> <a href="">Becuwe, Frank </a> (omvat)>
</ul>

     </div>




              </div>


            </div>

         </div>

      </div>
   </div>






























<!-- search 2 -->
<div class="row">
<div class="large-12 columns">

<div class="panel fl-block-search">
      <form name="" action="#" method="post" class="clearfix">
      <div class="searchBox">
          <input type='text' placeholder='zoek' />
          <button>zoeken</button>
          <small><a href="">Uitgebreid zoeken</a> &rsaquo;</small>
      </div>
      </form>
</div>
</div>
<!-- end search 2 -->




<!--
<a href="">Van Daele, Koen</a></li>
<a href="">Meylemans, Erwin</a></li>
<a href="">Cousserier, Katrien</a></li>
<a href="">Jansen, Isabelle </a></li>
<a href="">Hooft, Elise </a></li>
<a href="">Cherretté, Veerle </a></li>
<a href="">Kennes, Hilde </a></li>
<a href="">Driessen, Carolien </a></li>
<a href="">De Schutter, Maria </a></li>
<a href="">Jacobs, Bernadette </a></li>
<a href="">Michiels, Marijke </a></li>
<a href="">Buyle, Marianne </a></li>
<a href="">De Bodt, Vicky </a></li>
<a href="">Verwinnen, Katrien </a></li>
<a href="">Moeykens, Sofie </a></li>
<a href="">Braeken, Jo </a></li>
<a href="">Bergmans, Anna </a></li>
<a href="">Vynckier, Geert </a></li>
<a href="">Brees, Joris </a></li>
<a href="">Vanderhispallie, Eelkje </a></li>
<a href="">Meganck, Leen </a></li>
<a href="">Debonne, Vincent </a></li>
<a href="">Denis, Hans </a></li>
<a href="">Lo, Eva </a></li>
<a href="">Roose, Patrick </a></li>
<a href="">Heyn, Moira </a></li>
<a href="">Verhulst, Maryline </a></li>
<a href="">Vandesande, Aziliz </a></li>
<a href="">Ameels, Vera </a></li>
<a href="">Thomas, Hans </a></li>
<a href="">Daveloose, Barbara </a></li>
<a href="">De Haan, Aukje </a></li>
<a href="">Verboven, Hilde </a></li>
<a href="">Pieters, Marnix </a></li>
<a href="">Haneca, Kristof </a></li>
<a href="">Smets, Koen </a></li>
<a href="">Bartels, Walter </a></li>
<a href="">Buijs, Joke </a></li>
<a href="">Deforce, Koen </a></li>
<a href="">Hulstaert, Willem </a></li>
<a href="">van den Bossche, Herman </a></li>
<a href="">Verdurmen, Inge </a></li>
<a href="">Becuwe, Frank </a> (omvat)>
-->





{% endblock %}