{% extends "pyoes/layout.jinja2" %}

{% set app_package = 'pyoes' %}

{% set datum_copyright = '2013-2014' %}

{% set main_nav = [
	('home', 'Home', '/'),
	('burgerprofiel', 'Burgerprofiel', 'burgerprofiel'),
	('burgerprofiel2', 'Burgerprofiel aangepast', 'burgerprofiel2'),
	('headerlinks', 'Header links', 'headerlinks'),
	('vinden', 'Vinden', '#'),
	('pinpoints', 'Pinpoints', 'pinpoints'),
	('icons', 'Icons', 'icons')
]-%}


{% set dropdown_main_nav = [
	('home', 'Home', [
	('burgerprofiel', 'Burgerprofiel', 'burgerprofiel'),
	('burgerprofiel2', 'Burgerprofiel aangepast', 'burgerprofiel2'),
	('headerlinks', 'Header links', 'headerlinks'),
	('vinden', 'Vinden', '#'),
	('pinpoints', 'Pinpoints', 'pinpoints'),
	('icons', 'Icons', 'icons')])
]-%}

{% set login_nav = [('Aanmelden', '#')] -%}
{% set login_sub_nav = [('Afmelden', '/afmelden')] -%}

