

  <div class="large-6 columns">

      <!-- nieuws 1 -->
          {% include "includes/blokken/nieuws-1.jinja2" %}
      <!-- end nieuws 1 -->

  </div>


  <div class="large-6 medium-6 columns">

     <!-- search 2 -->
          {% include "includes/blokken/search-5.jinja2" %}
     <!-- end search 2 -->

  </div>





  <div class="large-6 medium-6 columns" style="padding:0">

      <div class="large-6 medium-6 columns">

      <!-- nieuwsfeed -->
          {% include "includes/blokken/nieuws-3.jinja2" %}
      <!-- end nieuwsfeed -->


      </div>



      <div class="large-6 medium-6 columns">

      <!-- promo -->
      {% include "includes/blokken/promo-1.jinja2" %}
      <!-- end promo -->


      </div>
  </div>




<!-- images large 3-->
     {% include "includes/elements/images-1.jinja2" %}
<!-- end images large 3 -->



  <div class="large-3 columns">

     <!-- statistieken  -->
        {% include "includes/elements/statistieken-1.jinja2" %}
     <!-- end statistieken  -->

  </div>


  <div class="large-3 columns">

     <!-- nieuwsbrief  -->
        {% include "includes/blokken/nieuwsbrief.jinja2" %}
     <!-- end nieuwsbrief  -->

  </div>


  <div class="large-3 columns">

     <!-- downloads  -->
        {% include "includes/blokken/downloads-1.jinja2" %}
     <!-- end downloads  -->

  </div>


  <div class="large-3 columns">

      <!-- social 1-->
          {% include "includes/blokken/social-1.jinja2" %}
      <!-- end social 1 -->

  </div>








  <div class="large-3 columns">

     <!-- statistieken  -->
        {% include "includes/blokken/evenementen-1.jinja2" %}
     <!-- end statistieken  -->

  </div>


  <div class="large-3 columns">

     <!-- agentschap  -->
        {% include "includes/blokken/agentschap-1.jinja2" %}
     <!-- end agentschap -->

  </div>


  <div class="large-3 columns">

     <!-- promo 2  -->
        {% include "includes/blokken/promo-2.jinja2" %}
     <!-- end promo 2  -->

  </div>


  <div class="large-3 columns">

      <!-- promo 3-->
          {% include "includes/blokken/promo-3.jinja2" %}
      <!-- end promo 3 -->

  </div>



  <div class="large-3 columns">

      <!-- promo 4 -->
          {% include "includes/blokken/promo-4.jinja2" %}
      <!-- end promo  4 -->

  </div>





