<div class="panel Searchbox">
<form name="" action="#" method="post" class="clearfix">

<div class="searchBox">
    <input type='text' placeholder='zoek foto' />
    <button>zoeken</button>
    <small><a href="" >Uitgebreid zoeken</a> &rsaquo;</small> 
</div>
</form> 




