{% extends "layout.jinja2" %}

{% block content %}


<!-- pagination -->
    <div class="pagination-centered">
      <ul class="pagination">
        <li class="arrow unavailable"><a href=""> &lsaquo; vorige</a></li>
        <li class=""><a href="">lijstscherm</a></li>
        <li class="arrow"><a href="">volgende  &rsaquo;</a></li>
      </ul>
    </div>
<!-- end pagination -->



<!-- content -->

<div class="row">
<div class="large-12 columns">
<div class="panel">


<header>
    <i class="fa fa-user actoren-icon-large"></i></a>
    <h1 style="margin:0">Van Daele Koen</h1>
    <h3><small>ID : 1</small></h3>
</header>


<table class="table">

    <tbody>
      <tr>
        <td style="width:150px">Afkorting</td>
        <td> - </td>
      </tr>

      <tr>
        <td>Actortype</td>
        <td>persoon</td>
      </tr>

      <tr>
        <td>Telefoon</td>
        <td>02/553.16.82</td>
      </tr>

      <tr>
        <td>Email werk</td>
        <td><a href="mailto:koen.vandaele@rwo.vlaanderen.be">koen.vandaele@rwo.vlaanderen.be</a></td>
      </tr>

      <tr>
        <td>Adres</td>
        <td> - </td>
      </tr>

      <tr>
        <td>Opmerkingen</td>
        <td> - </td>
      </tr>


    </tbody>
</table>

<!-- relaties -->

  <h6><small>Relaties</small></h6>




<!-- start row -->

<div class="row">

<div class="large-3 medium-3 columns">

    <div class="panel actoren-idcard">
     <a href="actorenfront/detail">
          <div class="actoren-icon-small clearfix">
          <i class="fa fa-user"></i>
          </div>
          <h3>Van Daele <br> Koen</h3>
          <small>ID : 1</small>
      </a>
    </div>

</div>


<div class="large-3 medium-3 columns">

    <div class="panel actoren-idcard">
     <a href="actorenfront/detail-bedrijf">
          <div class="actoren-icon-small clearfix">
          <i class="fa fa-building"></i>
          </div>
          <h3>Onroerend erfgoed</h3>
          <small>ID : 1</small>
     </a>
    </div>

</div>


<div class="large-3 medium-3 columns">

    <div class="panel actoren-idcard">
      <a href="actorenfront/detail">
          <div class="actoren-icon-small clearfix">
          <i class="fa fa-user"></i>
          </div>
          <h3>Van Daele <br> Koen</h3>
          <small>ID : 1</small>
      </a>
    </div>

</div>


<div class="large-3 medium-3 columns">

    <div class="panel actoren-idcard">
    <a href="actorenfront/detail-bedrijf">
          <div class="actoren-icon-small clearfix">
          <i class="fa fa-building"></i>
          </div>
          <h3>Onroerend erfgoed</h3>
          <small>ID : 1</small>
    </a>
    </div>

</div>

</div>

<!-- end row-->



<!-- start row -->

<div class="row">

<div class="large-3 medium-3 columns">

    <div class="panel actoren-idcard">
     <a href="actorenfront/detail">
          <div class="actoren-icon-small clearfix">
          <i class="fa fa-user"></i>
          </div>
          <h3>Van Daele <br> Koen</h3>
          <small>ID : 1</small>
      </a>
    </div>

</div>


<div class="large-3 medium-3 columns">

    <div class="panel actoren-idcard">
     <a href="actorenfront/detail-bedrijf">
          <div class="actoren-icon-small clearfix">
          <i class="fa fa-building"></i>
          </div>
          <h3>Onroerend erfgoed</h3>
          <small>ID : 1</small>
     </a>
    </div>

</div>


<div class="large-3 medium-3 columns">

    <div class="panel actoren-idcard">
      <a href="actorenfront/detail">
          <div class="actoren-icon-small clearfix">
          <i class="fa fa-user"></i>
          </div>
          <h3>Van Daele <br> Koen</h3>
          <small>ID : 1</small>
      </a>
    </div>

</div>


<div class="large-3 medium-3 columns">

    <div class="panel actoren-idcard">
    <a href="actorenfront/detail-bedrijf">
          <div class="actoren-icon-small clearfix">
          <i class="fa fa-building"></i>
          </div>
          <h3>Onroerend erfgoed</h3>
          <small>ID : 1</small>
    </a>
    </div>

</div>

</div>

<!-- end row-->

<!-- end relaties -->

<ul class="source-authors">
<li>Huidige status : Klad</li>
<li>Laatst gewijzigd door : <span class="author" itemprop="author" itemscope itemtype="http://schema.org/Person">Taeymma</span> op <time itemprop="datePublished" datetime="2009-05-06">2009-05-06 om 23:29:32</time></li>
<li>Aangemaakt door : <span class="author" itemprop="author" itemscope itemtype="http://schema.org/Person">Anoniem </span>op
<time itemprop="datePublished" datetime="2009-05-06">2009-05-06 om 23:29:32</time></li>
<li>Laatst bewerkt door : <span class="author" itemprop="author" itemscope itemtype="http://schema.org/Person">Vandaeko</span> op
<time itemprop="datePublished" datetime="2009-05-06">2009-05-06 om 23:29:32</time></li>
</ul>

</div>

</div>


</div>




<!-- search 2 -->
<div class="row">
<div class="large-12 columns">

<div class="panel fl-block-search">
      <form name="" action="#" method="post" class="clearfix">
      <div class="searchBox">
          <input type='text' placeholder='zoek' />
          <button>zoeken</button>
          <small><a href="">Uitgebreid zoeken</a> &rsaquo;</small>
      </div>
      </form>
</div>
</div>
<!-- end search 2 -->



{% endblock %}