

<!-- search 5 -->

<div class="large-12 ">
    <div class="panel fl-block-search">

<form name="" action="#" method="post" class="clearfix">

  <input type='text' placeholder='zoek' />
  <a href="#" class="button [tiny small large] right">ZOEKEN</a>

  <fieldset class="fl-block-search_fieldset">
     <select>
       <option value="">filter op</option>
       <option value="">1</option>
       <option value="">2</option>
       <option value="">3</option>
       <option value="">4</option>
     </select>
  </fieldset>

</form>

    </div>
</div>

<!-- end search 5 -->




