

<!-- promo zonder beeld met gekleurde bg-->

<div class="block-holder clearfix">

    <div class="fl-block style-3 ">

        <div class="block-date field"><i class="fa fa-calendar-o"></i> 23 april, 2013 </div>

        <div class="block-text field coloredbg">

        <h3><a href="#">Onderwijs bepalend voor succes in volwassen leven </a></h3>

        <p>Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Quis nostrum eliat sempris quam.</p>

        <a class="more" href="#" itemprop="url">lees verder  &rsaquo;</a>
        </div>

    </div>

</div>

<!-- end promo zonder beeld met gekleurde bg -->


