
<h4>280 reacties</h4>

<ul class="reactions">

  <li>
      <cite>naam</cite>
      <blockquote>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Morbi malesuada ut nisl iaculis interdum. Integer in mauris eu velit consequat pulvinar in et lectus.</blockquote>
      <span>12/01/15 14u34</span>
  </li>

  <li>
      <cite>naam</cite>
      <blockquote>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Morbi malesuada ut nisl iaculis interdum. Integer in mauris eu velit consequat pulvinar in et lectus.</blockquote>
      <span>12/01/15 14u33</span>
  </li>

</ul>