


<a href="#" data-reveal-id="myModal">Een dialoog venster</a>

<div id="myModal" class="reveal-modal" data-reveal>
  <h2>Lorem ipsum dolor sit amet</h2>
  <p class="lead">Lorem ipsum dolor sit amet</p>
  <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Cras leo lacus, ultrices in orci id, porttitor finibus metus. Pellentesque iaculis libero a erat tempor, id interdum lectus sodales. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Phasellus tempus feugiat tortor, congue ornare tellus tempus ac. Suspendisse ac sagittis orci, at iaculis lectus. Integer et nunc vel ante dictum sollicitudin. Nam ut sapien ac quam aliquet fermentum et et velit. Aliquam in tincidunt sem. Phasellus molestie metus elit, in semper arcu rhoncus ut.</p>
  <a class="close-reveal-modal">&#215;</a>
</div>


<br><br>


<div data-alert class="alert-box success">
  This is a success alert
  <a href="#" class="close">&times;</a>
</div>

<div data-alert class="alert-box alert-success">
  This is a success alert <a href="#" class="alert-link">link</a>
  <a href="#" class="close">&times;</a>
</div>



<div data-alert class="alert-box warning">
  This is a warning alert
  <a href="#" class="close">&times;</a>
</div>

<div data-alert class="alert-box alert-warning ">
  This is a warning alert <a href="#" class="alert-link">link</a>
  <a href="#" class="close">&times;</a>
</div>


<div data-alert class="alert-box info ">
  This is an info alert
  <a href="#" class="close">&times;</a>
</div>

<div data-alert class="alert-box alert-info">
  This is an info alert <a href="#" class="alert-link">link</a>
  <a href="#" class="close">&times;</a>
</div>

<div data-alert class="alert-box alert">
  This is an alert 
  <a href="#" class="close">&times;</a>
</div>

<div data-alert class="alert-box alert-danger">
  This is an alert <a href="#" class="alert-link">link</a>
  <a href="#" class="close">&times;</a>
</div>


<div data-alert class="alert-box secondary">
  This is a secondary alert.
  <a href="#" class="close">&times;</a>
</div>

<div data-alert class="alert-box custom">
  This is a custom alert.
</div>
