
<!-- start large images -->

      <div class="large-12 columns">

        <div class="panel">

          <h4 class="header-img-panel">Recent toegevoegd</h4>

             <div class="large-3 medium-3 columns fl-block-largeimage">
               <a href="">
                <img src="https://inventaris.onroerenderfgoed.be/afbeeldingen/187263?size=medium.jpg"/>
                <h5>Opgaande es</h5>
                <small>ID : 1247 </small>
                <!--time itemprop="datePublished" datetime="" class="posted">10 december 2014</time -->
              </a>
              </div>


            <div class="large-3 medium-3 columns fl-block-largeimage">
               <a href="">
                <img src="https://inventaris.onroerenderfgoed.be/afbeeldingen/189624?size=medium.jpg"/>
                <h5>Weerhaag van meidoorn bij hoogstamboomgaard</h5>
                <small>ID : 1070</small>
              </a>
            </div>


            <div class="large-3 medium-3 columns fl-block-largeimage">
               <a href="">
                <img src="https://inventaris.onroerenderfgoed.be/afbeeldingen/189987?size=medium.jpg"/>
                <h5>Weerhaag van meidoorn bij hoogstamboomgaard</h5>
                <small>ID : 1184</small>
              </a>
            </div>

            <div class="large-3 medium-3 columns fl-block-largeimage">
               <a href="">
                <img src="https://inventaris.onroerenderfgoed.be/afbeeldingen/189622?size=medium3.jpg"/>
                <h5>Weerhaag van meidoorn als veekering</h5>
                <small>ID : 1069</small>
              </a>
            </div>


            <div class="fl-block">
                 <div class="field"><a class="more" href="#">toon alles  &rsaquo;</a></div>
            </div>


        </div>

      </div>


<!-- end large images -->


