{% extends "layout.jinja2" %}
{% block content %}

<br>
<h1 class="text-center">Blokken</h1>

<div class="row">

<div class="large-12 columns">

<!-- nieuws + content-->

<p class="text-center">nieuws + content</p>
{% include "includes/blokken/nieuws-1.jinja2" %}

<!-- nieuws compact-->
<p class="text-center">nieuws compact</p>
{% include "includes/blokken/nieuws-2.jinja2" %}

<!-- nieuwsfeed-->
<p class="text-center">nieuwsfeed</p>
{% include "includes/blokken/nieuws-3.jinja2" %}

<!-- nieuwsbrief-->
<p class="text-center">nieuwsbrief</p>
{% include "includes/blokken/nieuwsbrief.jinja2" %}

<!-- zoek -->
<p class="text-center">zoekbox-1</p>
{% include "includes/blokken/search-1.jinja2" %}

<!-- zoek 2 -->
<p class="text-center">zoekbox-2</p>
{% include "includes/blokken/search-2.jinja2" %}

<!-- zoek 3 -->
<p class="text-center">zoekbox-3 extended</p>
{% include "includes/blokken/search-3ext.jinja2" %}

<!-- zoek 4 -->
<p class="text-center">zoekbox-4</p>
{% include "includes/blokken/search-4.jinja2" %}

<!-- zoek 5 -->
<p class="text-center">zoekbox-5</p>
{% include "includes/blokken/search-5.jinja2" %}


<!-- promo-->
<p class="text-center">promo-1</p>
{% include "includes/blokken/promo-1.jinja2" %}

<!-- promo 2 -->
<p class="text-center">promo-2</p>
{% include "includes/blokken/promo-2.jinja2" %}

<!-- promo 3 -->
<p class="text-center">promo-3</p>
{% include "includes/blokken/promo-3.jinja2" %}

<!-- promo 4 -->
<p class="text-center">promo-4</p>
{% include "includes/blokken/promo-4.jinja2" %}


<!-- agentschap 1 -->
<br>
<p class="text-center">agentschappen</p>

{% include "includes/blokken/agentschap-1.jinja2" %}

<!-- downloads  -->
<br>
<p class="text-center">downloads</p>
{% include "includes/blokken/downloads-1.jinja2" %}

<!-- evenementen  -->
<br>
<p class="text-center">evenementen</p>
{% include "includes/blokken/evenementen-1.jinja2" %}


<!-- social block -->
<br>
<p class="text-center">social</p>
{% include "includes/blokken/social-1.jinja2" %}



<!-- social twitter -->
<br>
<p class="text-center">twitter social nog te maken</p>

</div>

</div>

{% endblock %}