
<!-- nieuwsbrief -->

    <div class="fl-block style-2">

        <div class="panel fl-block-search">

            <h4 class="block-title naked">Nieuwsbrief</h4>

            <form>

              <div class="row">
                <div class="large-12 columns">
                  <input type="text" placeholder="naam" />
                </div>
              </div>

              <div class="row">
                <div class="large-12 columns">
                  <input type="text" placeholder="emailadres" />
                </div>
              </div>

              <a itemprop="url" href="#" class="button expand [tiny small large]">VERSTUREN</a>

            </form>

        </div>

    </div>


<!-- end nieuwsbrief -->