{% extends "layout.jinja2" %}

{% block content %}

<section class="content sub">
	<div class="row">
		<div class="small-3 columns no-pad-left">
			<aside class="sidebar sidebar-left">
				<div class="widget widget-list">
					<ul class="sub-pages">
						<li class="first"><a href="#">Lorem</a></li>
						<li><a href="#">Ipsum</a></li>
						<li class="last"><a href=/contact">Contact</a></li>
					</ul>
				</div>
			</aside>
		</div>
		<div class="small-9 columns middle-content sub">
			<div class="row">
				<div class="small-12 columns no-pad-right">
					<h1>Over deze site</h1>
					<p class="intro">Deze site geeft een overzicht van het Onroerend Erfgoed in al zijn facetten in Vlaanderen.</p>
				</div>
			</div>
			<div class="row">
				<div class="small-8 columns">
					<article class="main-content">
						<div class="body">
							<p>Lorem Ipsum blablabla ...</p>
							<p>Nog meer zaken die ik nu niet wil schrijven.</p>
							<p>En nog een beetje.</p>
						</div>
					</article>
				</div>
				<div class="small-4 columns no-pad-right">
					<aside class="sub-side sub-page">
						<div class="info-caption sub">
							<div class="inner">
							</div>
							<div class="bottom">
								<h2>Contacteer ons</h2>
								<p>Onroerend erfgoed</p>
								<p>Phoenixgebouw 1ste verd. + gelijkvl<br />
								Koning Albert II-laan 19, bus 5<br />
								1210 Brussel</p>
								<p>T. <strong>05 553.16.50</strong></p>
								<p><a href="mailto:info@onroerenderfgoed.be">info@onroerenderfgoed.be</a></p>
							</div>
						</div>
					</aside>
				</div>
			</div>
		</div>
	</div>
</section>

{% endblock %}
