{% extends "pyoes/layout.jinja2" %}

{% block content %}


<!-- pagination -->
    <div class="pagination-centered">
      <ul class="pagination">
        <li class="arrow unavailable"><a href=""> &lsaquo; vorige</a></li>
        <li class=""><a href="">lijstscherm</a></li>
        <li class="arrow"><a href="">volgende  &rsaquo;</a></li>
      </ul>
    </div>
<!-- end pagination -->




<!-- content -->
<div class="row">
  <div class="large-12 columns">
    <div class="panel">


      <div class="row">

          <div class="large-6 medium-6 columns">
          <figure class="bb-imagelarge"> <img src="http://placehold.it/494x278"> </figure>
          </div>


          <div class="large-6 medium-6 columns">

          <dl class="caption-info">
              <dt>Originele afbeelding</dt>
              <dd>2014-05-02 14.34.53.jpg ( 3264 x 1840 )</dd>
              <dt>Aangemaakt door</dt>
              <dd>nepgebruiker</dd>
              <dt>Aangemaakt op</dt>
              <dd>2014-09-23 16:11:27</dd>
              <dt>Formaten</dt>
              <dd>
                <a href="">small</a> <small> ( 240x135 ) </small><br>
                <a href="">medium</a> <small> ( 500x281 ) </small><br>
                <a href="">large</a> <small>  ( 1024x577 ) </small><br>
                <a href="">full</a> <small> ( 3264x1840 ) </small><br>
                <a href="">square</a> <small> ( 150x150 ) </small><br>
                <a href="">original</a> <small> ( 3264x1840 )
              </dd>
          </dl>

          </div>

      </div>

<hr>

       <div class="row">

             <div class="large-6 medium-6 columns">

                 <dl class="caption-info">
                    <dt>Titel</dt>
                    <dd>2014-05-02 14.34.53.jpg</dd>
                    <dt>Beschrijving</dt>
                    <dd>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nam sit amet lorem et purus venenatis posuere at vel arcu. Sed risus metus, laoreet sed dictum sit amet, interdum nec velit. Fusce purus tellus, congue at lacus vel, dictum varius quam. Proin mattis tellus mollis tortor elementum, id gravida augue fringilla. Integer sodales massa eget nibh suscipit consequat. Nulla facilisi. </dd>
                    <dt>Opmerkingen</dt>
                    <dd>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nam sit amet lorem et purus venenatis posuere at vel arcu. Sed risus metus, laoreet sed dictum sit amet, interdum nec velit.</dd>
                    <dt>Trefwoorden</dt>
                    <dd>Geen trefwoord beschikbaar</dd>
                </dl>

             </div>


            <div class="large-6 medium-6 columns">

                   <dl class="caption-info">
                   <dt>Copyright</dt>
                   <dd>Onroerend Erfgoed</dd>
                   <dt>Zichtbaarheid</dt>
                   <dd>Publiek</dd>
                   <dt>Gefotografeerd op</dt>
                   <dd>2014-05-02 14:34:53</dd>
                   <dt>Adres</dt>
                   <dd>Geen adresgegevens beschikbaar</dd>
                   </dl>

            </div>

      </div>
    </div>


{% include "blokken/search-2" %}


  </div>
</div>
<!-- end content -->






{% endblock %}