

<div class="row">

  <div class="large-12 columns">

      <div class="panel">
        <h2>Content</h2>
        <p><strong>Boxes with a white background include a div.panel element. <br>
        You can remove the 'panel' class for no white background and padding. It's not required at all for the grid. </strong></p>
         <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Cras leo lacus, ultrices in orci id, porttitor finibus metus. Pellentesque iaculis libero a erat tempor, id interdum lectus sodales. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Phasellus tempus feugiat tortor, congue ornare tellus tempus ac. Suspendisse ac sagittis orci, at iaculis lectus. Integer et nunc vel ante dictum sollicitudin. Nam ut sapien ac quam aliquet fermentum et et velit. Aliquam in tincidunt sem. Phasellus molestie metus elit, in semper arcu rhoncus ut.</p>
      </div>

  </div>

</div>