

<table class="table border">
    <thead>
      <tr>
        <th></th>
        <th>2008</th>
        <th>2009</th>
        <th>2010</th>
        <th>2011</th>
      </tr>
    </thead>
    <tbody>
      <tr>
        <td>Lorem ipsum dolor sit amet, consectetur adipiscing elit</td>
        <td>65.565</td>
        <td>487.455</td>
        <td>254.786</td>
        <td>254.786</td>
      </tr>
      <tr>
        <td>Lorem ipsum dolor sit amet, consectetur adipiscing elit</td>
        <td>65.565</td>
        <td>487.455</td>
        <td>254.786</td>
        <td>254.786</td>
      </tr>
      <tr>
        <td>Lorem ipsum dolor sit amet, consectetur adipiscing elit</td>
        <td>5.565</td>
        <td>487.455</td>
        <td>2.786</td>
        <td>24.786</td>
      </tr>
    </tbody>
</table>

