
<!-- agentschappen -->

<div class="block-holder clearfix">

    <div class="fl-block style-1">

        <h4 class="block-title field">Agentschappen</h4>

            <div class="block-text field">

                <p>Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh:</p>

                <ul class="disk">
                    <li><a href="#">Departement Onderwijs en Vorming</a></li>
                    <li><a href="#">Agentschap voor Hoger Onderwijs, Volwassenen</a></li>
                    <li><a href="#">Onderwijs en Studietoelagen</a></li>
                    <li><a href="#">Agentschap voor Infrastructuur in het Onderwijs</a></li>
                    <li><a href="#">Agentschap voor Kwaliteitszorg in Onderwijs en Vorming</a></li>
                </ul>


             </div>

    </div>

</div>



