

<!-- downloads -->

   <div class="fl-block style-3">

      <h4 itemprop="name" class="block-title field">Downloads</h4>
      <div class="field full download"><a itemprop="url" href="#">De Onderwijsspiegel 2013  <i class="fa fa-download"></i></a></div>
      <div class="field full download"><a itemprop="url" href="#">Studietoelagen 2013 <i class="fa fa-download"></i></a></div>
      <div class="field full download"><a itemprop="url"  href="#">Subsidies &amp; steun 2013 <i class="fa fa-download"></i></a></div>
      <div class="field"><a itemprop="url" class="more" href="#">meer downloads  &rsaquo;</a></div>

   </div>

<!-- end downloads -->



