
<!-- search 4  -->

	<div class="large-12 columns">
		<div class="panel fl-block-search">

     	 <form name="" action="#" method="post" class="clearfix">

			<div class="searchBox clearfix">
			    <input type='text' placeholder='zoek' />
			    <button>zoeken</button>
			    <small><a href="uitgebreid-zoeken">Uitgebreid zoeken</a> &rsaquo;</small>
			</div>

 			<div class="row">

			  <div class="large-8 medium-8 columns">
			    	<h5>Er zijn geen resultaten beschikbaar</h5>
			  </div>

			  <div class="large-4 medium-4 columns">
				  <select>
                  <option value="">sorteer op</option>
                  <option value="">datum/aflopend</option>
                  <option value="">datum/oplopend</option>
                  <option value="">titel/aflopend</option>
                  <option value="">titel/oplopend</option>
                  </select>
			  </div>

			</div>

		</form>

        </div>
     </div>


<!-- end search 4 -->