<div class="pagination-centered">
  <ul class="pagination">
    <li class="arrow unavailable"><a href=""> &lsaquo; vorige</a></li>
    <li class=""><a href="">lijstscherm</a></li>
    <li class=""><a href="">volgende  &rsaquo;</a></li>
  </ul>
</div>





