

<table class="table">
    <thead>
      <tr>
        <th>#</th>
        <th>Name</th>
        <th>Address</th>
        <th>Mail</th>
      </tr>
    </thead>
    <tbody>
      <tr>
        <td>1</td>
        <td>Thomas bell</td>
        <td>Brick lane, London</td>
        <td>thomas@yahoo.com</td>
      </tr>
      <tr>
        <td>2</td>
        <td>Yan Chapel</td>
        <td>Toronto, Australia</td>
        <td>Yan@yahoo.com</td>
      </tr>
      <tr>
        <td>3</td>
        <td>Pit Sampras</td>
        <td>Berlin, Germany</td>
        <td>Pit@yahoo.com</td>
      </tr>
      <tr>
        <td>4</td>
        <td>Yan Chapel</td>
        <td>Toronto, Australia</td>
        <td>Yan@yahoo.com</td>
      </tr>
    </tbody>
</table>