{% extends "layout.jinja2" %}
{% block content %}

  <p class="text-center">
<a href="beheersplannen/result">resultaat pagina</a>

<!-- content -->

    <div class="row">
      <div class="large-12 columns">

        <div class="panel">

            <div class="row">

              <div class="large-12 columns" style="margin-bottom:20px">
              <h1>Welkom op de beheersplannendatabank.</h1>
              </div>

              <div class="large-6 medium-6 columns">


              <p>Het beheer van onroerend erfgoed is een ruim begrip. Het slaat op alle werken, maatregelen en handelingen die de waarden en kenmerken van het erfgoed in stand houden, verbeteren of herstellen.</p>
              <p>Daarbij is het belangrijk na te denken over de ambities op langere termijn.</p>
              <p>Die kun je concretiseren in een beheersplan voor het onroerend goed: een document waarin je onder meer vastlegt welke werkzaamheden waar en wanneer nodig zijn. Je kan hier al deze beheersplannen raadplegen</p>

              </div>


              <div class="large-6 medium-6 columns vruler">

                  <i class="fa fa-search icon-large-left"></i>
                  <h3>Op zoek in de databank?</h3>
                  <p>Zoeken gaat eenvoudig. Je kan gebruik maken van een vrij zoekveld. Hieronder kan je ook filteren op
                  beheersplantype.</p>

                  <i class="fa fa-question-circle icon-large-left"></i>
                  <h3>Vragen?</h3>
                  <p>Stel je fouten vast of heb je een vraag over een beheersplan? <br>
                  Mail dan naar <a href="mailto:">???</a>.</p>

              </div>

           </div>

        </div>
      </div>
    </div>
<!-- end content -->



<!-- search -->

<!-- search 3 extended -->

<div class="row">
    <div class="large-12 columns">
        <div class="fl-block-search">

            <div class="panel">

                <div class="row">
                  <form name="" action="#" method="post" class="clearfix">

                        <div class="large-12 medium-12 columns">

                        <div class="searchBox">
                             <input type='text' placeholder='zoek een beheersplan' />
                             <button>zoek</button>
                             </div>
                        </div>

                       </div>
                  </form>
               </div>

           </div>

       </div>
   </div>
</div>






<!-- end search 3 extended-->
<!-- end search -->




{% endblock %}