$font-family-light-serif: "Flanders Art Sans Light", Arial, sans-serif !default;
$font-family-bold-serif: "Flanders Art Sans Bold", Arial, sans-serif !default;
$font-family-sans-serif: "Flanders Art Sans", Arial, sans-serif !default;
$font-family-medium-serif: "Flanders Art Sans Medium", Arial, sans-serif !default;
$font-family-serif: Calibri, Georgia,serif !default;
$font-family-monospace: Consolas, "Liberation Mono", Courier, monospace !default;

$primary-color: #944EA1 !default;
$secondary-color: #e7e7e7 !default;
$alert-color: #FF0000 !default;    
$success-color: #43AC6A !default;  
$warning-color: #f08a24 !default;  
$info-color: #a0d3e8 !default;   
$custom-color:#FFFFCC !default; 

$very-dark-purple: rgb(33,7,41); //#210729
$dark-purple    : rgb(117,63,127); 	// #753F7F  
$mid-purple     : rgb(148,78,161); 	// #944EA1
$light-purple   : rgb(176,93,191); 	// #B05DBF
$white          : rgb(255,255,255); // #FFFFFF
$black          : rgb(0, 0, 0);		// #000000
$dark-gray      : rgb(63,56,64); 	// #3F3840
$mid-gray       : rgb(229,229,229); // #E5E5E5
$light-gray     : rgb(237,237,237); // #EDEDED
$gray           : rgb(213,213,213); // #D5D5D5
$silver         : rgb(152,152,152); // #989898
$steel          : #666666 !default;
$jet            : #333333 !default;
$ghost          : #FAFAFA;
$aluminum       : #efefef;
$white-gray     : #fbfbfb; // hover color 
$jumbo       	: #888888;
$link-color     : #0075db;
// social 

$soc-twitter 	: #2da5da;
$soc-facebook 	: #3567a6;
$soc-mail 	    : #926da5;
$soc-linkedin 	: #007ab9;
$soc-twitter_hover 	: #2690bf;
$soc-facebook_hover : #255592;
$soc-mail_hover 	: #7a588b;
$soc-linkedin_hover : #006ca4;

// OE specific

$fresh-blue     : #2da3ce;
$gray-blue      : #86abbe;