
<!-- social on page -->

<div class="fl-block style-3">
	<h4 class="block-title field">Volg ons</h4>
	<div class="field full social twitter"><a href="#"><i class="fa fa-twitter"></i> Twitter</a></div>
	<div class="field full social facebook"><a href="#"><i class="fa fa-facebook-square"></i> Facebook</a></div>
	<div class="field full social mail"><a href="#"><i class="fa fa-envelope"></i> mail</a></div>
	<div class="field full social linkedin"><a href="#"><i class="fa fa-linkedin"></i> LinkedIn</a></div>

</div>

<!-- end social on page -->
