{% extends "layout.jinja2" %}
{% block content %}


<div class="row">
	<div class="large-12 columns">


<h1 class="text-center">Images</h1>


{% include "includes/elements/images-1.jinja2" %}


<hr>

{% include "includes/elements/images-2.jinja2" %}



	</div>
</div>





{% endblock %}