<!-- footer -->
<footer id="footer-bottom" role="contentinfo">
  <div class="footer-bottom-inner inner">
    <nav class="footer-doormat clearfix">
      <div class="large-4 columns">
        {% block footer scoped %}
          <ul style="padding: 0">
            {% for caption, href in footer_nav %}
              <li><a target="_blank" href="{{ href }}">-&nbsp;{{ caption }}</a></li>
            {% endfor %}
          </ul>
        {% endblock %}
      </div>
      <div class="large-5 columns">
        <a class="mailtolink" href="mailto:ict@onroerenderfgoed.be">Technische vraag? Mail ons via ict@onroerenderfgoed.be</a>
      </div>
      <div class="large-3 columns right">
        <ul class="soclogolist right">
          <li><span class="facebook"><a href="https://www.facebook.com/onroerenderfgoed" target="_blank"><i class="fa fa-facebook-square"></i></a></span></li>
          <li><span class="twitter"><a href="https://twitter.com/vioe" target="_blank"><i class="fa fa-twitter"></i></a></span></li>
          <li><span class="linkedin"><a href="https://www.linkedin.com/company/onroerend-erfgoed-flanders-heritage-" target="_blank"><i class="fa fa-linkedin"></i></a></span></li>
          <li><span class="slideshare"><a href="http://www.slideshare.net/VIOE" target="_blank"><i class="fa fa-slideshare"></i></a></span></li>
        </ul>
      </div>
    </nav>
  </div>
</footer>
<!-- end footer -->
