
     
<!-- nieuws 2 -->

  <div class="fl-block style-2">

      <h4 class="block-title field"><a href="#">Nieuws</a></h4>

      <div itemscope="" itemtype="http://schema.org/Article" class="field full news">
            <a itemprop="url" href="#">
                <h5 itemprop="name">Vlaamse overheid is werkgever van het jaar</h5> 
                <time itemprop="datePublished" datetime="2014-04-30">30 april 2014</time>
            </a>
      </div>

      <div itemscope="" itemtype="http://schema.org/Article" class="field full news">
            <a itemprop="url" href="#">
                <img itemprop="image" src="https://inventaris.onroerenderfgoed.be/afbeeldingen/180002?size=small.png" width="90" alt="Alt descritpion" />
                <h5 itemprop="name">De stemmen zijn geteld</h5> 
                <time itemprop="datePublished" datetime="2014-04-30">30 april 2014</time>
            </a>
      </div>
   
      <div itemscope="" itemtype="http://schema.org/Article" class="field full news">
           <a itemprop="url" href="#">
                <h5 itemprop="name">Huurpremie na 4 jaar wachten op sociale woning</h5> 
                <time itemprop="datePublished" datetime="2014-04-30">30 april 2014</time>
           </a>
      </div>

    
    <div class="field"><a itemprop="url" class="more" href="#">toon alles  &rsaquo;</a></div>
    

  </div>

<!-- end nieuws 2 -->