{% extends "layout.jinja2" %}

{% block content %}



<br>


    <div class="row">

      <div class="large-12 columns">


   <div class="panel">

    <ul>
      <li><a href="grids">Grids</a></li>
      <li><a href="blokken">Blokken</a></li>
      <li><a href="typo">Typo / Headings / Iconlist</a></li>
      <li><a href="navigation">Navigatie types</a></li>
      <li><a href="colors">Colors</a></li>
      <li><a href="elements">Elementen</a></li>
      <li><a href="images">Images</a></li>
      <li>Media</li>
    </ul>

    <hr>

      <ul>
      <li><a href="article">Basic article page 8/4</a></li>
      <li><a href="article9-3">Basic article page 9/3</a></li>
      </ul>

    <hr>

    <ul>
      <li><a href="beeldbank">Theme Beeldbank</a></li>
      <li><a href="beeldbank-zoeken">Theme Beeldbank uitgebreid zoeken</a></li>
      <li><a href="beeldbank-detail">Theme Beeldbank detail</a></li>
    </ul>

    <hr>
    <ul>
      <li><a href="inventaris">Theme Inventaris</a></li>
      <li><a href="inventaris-article">Theme Inventaris base article <small>(schets)</small></a></li>
      <li><a href="inventaris-articleID">Theme Inventaris article ID 2 col 9/3 <small>(schets)</small></a></li>
      <li><a href="inventaris-articleIDv2">Theme Inventaris article ID 2 col 9/3 <small>(schets)</small></a></li>
      <li><a href="inventaris-articleIDfull">Theme Inventaris article ID full width <small>(schets)</small></a></li>
      <li><a href="inventaris-articleIDfullv2">Theme Inventaris article ID full v2 width <small>(schets)</small></a></li>
      <li><a href="inventaris-articleIDfullv3">Theme Inventaris article ID full v3 width <small>(schets)</small></a></li>
      <li><a href="inventaris-zoekoverzicht">Theme Inventaris zoekoverzicht 2 col <small>(schets)</small></a></li>
      <li>Theme Inventaris print article</li>
    </ul>

   <!   <hr>

    <ul>
      <li><a href="geoportaal">Theme Geoportaal</a></li>
    </ul>

      <hr>

    <ul>
      <li><a href="beheersplannen">Theme Beheersplannen</a></li>
    </ul>

 <hr>

    <ul>
      <li><a href="actorenzoek">Zoekactoren</a></li>
    </ul>


    <ul>
      <li><a href="actorenfront">Zoekactoren front-end</a></li>
    </ul>

    <hr>
 <ul>
      <li><a href="beheersplannen">Beheersplannen</a></li>
    </ul>
    <hr>
 <ul>
      <li><a href="postregistratie">Postregistratie</a></li>
    </ul>
<hr>
<ul>
      <li><a href="besluitendatabank">Besluiten</a></li>
    </ul>



       </div>
   </div>
    </div>

{% endblock %}

{% block footer %}
    {% include "pyoes/footer.jinja2" %}
{% endblock %}