{% extends "inventaris-layout.jinja2" %}

{% block content %}
<div class="row">

<div class="large-6 columns ">



<!-- nieuws -->

<div class="fl-block style-2">

    <h4 class="block-title field"><a href="#">Nieuws</a></h4>
    <div class="field full news">
      <a href="#">
          <h5>Vlaamse overheid is werkgever van het jaar</h5> 
          21 mei 2014
      </a>
    </div>
    <div class="field full news">
      <a href="#">
        <figure><img src="https://inventaris.onroerenderfgoed.be/afbeeldingen/180002?size=small.png" width="80" alt="Alt descritpion" /></figure>
          <h5>De stemmen zijn geteld</h5> 
          23 mei 2014
      </a>
    </div>
    <div class="field full news">
      <a href="#">
             <figure><img src="https://inventaris.onroerenderfgoed.be/afbeeldingen/180002?size=small.png" width="80" alt="Alt descritpion" /></figure>
          <h5>Vermijd problemen door hitte en ozon</h5> 
          20 mei 2014
      </a>
    </div>
    <div class="field full news">
      <a href="#">
          <h5>Huurpremie na 4 jaar wachten op sociale woning</h5> 
          30 april 2014
      </a>
    </div>

      <div class="field full news">
      <a href="#">
          <h5>Huurpremie na 4 jaar wachten op sociale woning</h5> 
          30 april 2014
      </a>
    </div>

      <div class="field full news">
      <a href="#">
          <h5>Huurpremie na 4 jaar wachten op sociale woning</h5> 
          30 april 2014
      </a>
    </div>
    
    <div class="field"><a class="more" href="#">toon alles  &rsaquo;</a></div>
    

</div>
<!-- end nieuws -->


</div>





<div class="large-6 columns">

    <div class="large-6 columns">

      
            <!-- nieuws -->

<div class="fl-block style-2">

    <h4 class="block-title field"><a href="#">Nieuws</a></h4>
    <div class="field full news">
      <a href="#">
          <h5>Vlaamse overheid is werkgever van het jaar</h5> 
          21 mei 2014
      </a>
    </div>
    <div class="field full news">
      <a href="#">
        <figure><img src="https://inventaris.onroerenderfgoed.be/afbeeldingen/180002?size=small.png" width="80" alt="Alt descritpion" /></figure>
          <h5>De stemmen zijn geteld</h5> 
          23 mei 2014
      </a>
    </div>
    <div class="field full news">
      <a href="#">
             <figure><img src="https://inventaris.onroerenderfgoed.be/afbeeldingen/180002?size=small.png" width="80" alt="Alt descritpion" /></figure>
          <h5>Vermijd problemen door hitte en ozon</h5> 
          20 mei 2014
      </a>
    </div>
    <div class="field full news">
      <a href="#">
          <h5>Huurpremie na 4 jaar wachten op sociale woning</h5> 
          30 april 2014
      </a>
    </div>

      <div class="field full news">
      <a href="#">
          <h5>Huurpremie na 4 jaar wachten op sociale woning</h5> 
          30 april 2014
      </a>
    </div>

      <div class="field full news">
      <a href="#">
          <h5>Huurpremie na 4 jaar wachten op sociale woning</h5> 
          30 april 2014
      </a>
    </div>
    
    <div class="field"><a class="more" href="#">toon alles <i class="fa fa-chevron-right"></i></a></div>
    

</div>
<!-- end nieuws -->
    

    </div>

    <div class="large-6 columns">

      
            <!-- nieuws -->

<div class="fl-block style-3">

    <h4 class="block-title field"><a href="#">Nieuws</a></h4>
    <div class="field full news">
      <a href="#">
          <h5>Vlaamse overheid is werkgever van het jaar</h5> 
          21 mei 2014
      </a>
    </div>
    <div class="field full news">
      <a href="#">
        <figure><img src="https://inventaris.onroerenderfgoed.be/afbeeldingen/180002?size=small.png" alt="Alt descritpion" /></figure>
          <h5>De stemmen zijn geteld</h5> 
          23 mei 2014
      </a>
    </div>
    <div class="field full news">
      <a href="#">
             <figure><img src="https://inventaris.onroerenderfgoed.be/afbeeldingen/180002?size=small.png" alt="Alt descritpion" /></figure>
          <h5>Vermijd problemen door hitte en ozon</h5> 
          20 mei 2014
      </a>
    </div>
    <div class="field full news">
      <a href="#">
          <h5>Huurpremie na 4 jaar wachten op sociale woning</h5> 
          30 april 2014
      </a>
    </div>

      <div class="field full news">
      <a href="#">
          <h5>Huurpremie na 4 jaar wachten op sociale woning</h5> 
          30 april 2014
      </a>
    </div>

      <div class="field full news">
      <a href="#">
          <h5>Huurpremie na 4 jaar wachten op sociale woning</h5> 
          30 april 2014
      </a>
    </div>
    
    <div class="field"><a class="more" href="#">toon alles  &rsaquo;</a></div>
    

</div>
<!-- end nieuws -->

    </div>

</div>


</div>
<!-- end row -->








 
    <div class="row">

      <div class="large-12 columns">


        <div class="panel">


        <h1>Heading 1</h1>
        <h2>Heading 2</h2>
        <h3>Heading 3</h3>
        <h4>Heading 4</h4>
        <h5>Heading 5</h5>
        <h6>Heading 6</h6>
       
  
        <h1>Heading 1</h1>
   
        <article>
        Maecenas ac tortor nec <strong>ligula facilisis commodo</strong>. Etiam cursus augue ac interdum lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Suspendisse libero magna, volutpat vel massa sed, mollis hendrerit nisi. Quisque non augue a nisi auctor molestie ac sed turpis. Phasellus pulvinar, orci nec condimentum fringilla, mi arcu iaculis metus.
        </article>
        
      
        
        <h2>Heading 2</h2>

       <p>
        <b>Maecenas ac tortor nec ligula facilisis commodo</b>. Etiam cursus augue ac interdum lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Suspendisse libero magna, volutpat vel massa sed, mollis hendrerit nisi. Quisque non augue a nisi auctor molestie ac sed turpis. Phasellus pulvinar, orci nec condimentum fringilla, mi arcu iaculis metus.
        </p>


        <h3>Heading 3</h3>

        <p>
        Maecenas ac tortor nec ligula facilisis commodo. Etiam cursus augue ac interdum lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Suspendisse libero magna, volutpat vel massa sed, mollis hendrerit nisi. Quisque non augue a nisi auctor molestie ac sed turpis. Phasellus pulvinar, orci nec condimentum fringilla, mi arcu iaculis metus.
        </p>

        <h4>Heading 4</h4>
        <p>
        Maecenas ac tortor nec ligula facilisis commodo. Etiam cursus augue ac interdum lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Suspendisse libero magna, volutpat vel massa sed, mollis hendrerit nisi. Quisque non augue a nisi auctor molestie ac sed turpis. Phasellus pulvinar, orci nec condimentum fringilla, mi arcu iaculis metus.
        </p>

        <h5>Heading 5</h5>
        <p>
        Maecenas ac tortor nec ligula facilisis commodo. Etiam cursus augue ac interdum lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Suspendisse libero magna, volutpat vel massa sed, mollis hendrerit nisi. Quisque non augue a nisi auctor molestie ac sed turpis. Phasellus pulvinar, orci nec condimentum fringilla, mi arcu iaculis metus.
        </p>

        <h6>Heading 6</h6>
        <p>
        Maecenas ac tortor nec ligula facilisis commodo. Etiam cursus augue ac interdum lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Suspendisse libero magna, volutpat vel massa sed, mollis hendrerit nisi. Quisque non augue a nisi auctor molestie ac sed turpis. Phasellus pulvinar, orci nec condimentum fringilla, mi arcu iaculis metus.
        </p>






<hr>








        Maecenas ac tortor nec ligula facilisis commodo. Etiam cursus augue ac:

        <ul>
          <li>massa sed, mollis hendrerit nisi</li>
          <li>libero magna, volutpat vel massa sed</li>
        </ul> 
        

     
      </div>

   

       </div>
        </div>


     


    </div>

{% endblock %}
