{% extends "layout.jinja2" %}

{% block content %}  


<h1 class="text-center">Grids</h1>

<p class="text-center">type 1</p>
{% include "includes/grids/grid-1.jinja2" %}

<p class="text-center">type 2</p>
{% include "includes/grids/grid-2.jinja2" %}

<p class="text-center">type 3</p>
{% include "includes/grids/grid-3.jinja2" %}

<p class="text-center">type 4</p>
{% include "includes/grids/grid-4.jinja2" %}

<p class="text-center">type 5</p>
{% include "includes/grids/grid-5.jinja2" %}

<p class="text-center">type 6</p>
{% include "includes/grids/grid-6.jinja2" %}

<p class="text-center">type 7</p>
{% include "includes/grids/grid-7.jinja2" %}

<p class="text-center">type 8</p>
{% include "includes/grids/grid-8.jinja2" %}

<p class="text-center">type 9</p>
{% include "includes/grids/grid-9.jinja2" %}

<p class="text-center">type 10</p>
{% include "includes/grids/grid-10.jinja2" %}

<p class="text-center">type 11</p>
{% include "includes/grids/grid-11.jinja2" %}

<p class="text-center">type 12</p>
{% include "includes/grids/grid-12.jinja2" %}

<p class="text-center">type 13</p>
{% include "includes/grids/grid-13.jinja2" %}

<hr>
<p class="text-center">type 14 : An example for Inventaris</p>
{% include "includes/grids/grid-14.jinja2" %}


{% endblock %}