   
     
<!-- nieuwsfeed -->


      <div class="fl-block style-2">

        <h4 class="block-title field"><a itemprop="url" href="#">Nieuwsfeed</a></h4>

          <div itemscope="" itemtype="http://schema.org/Article" class="field full rss">
           <a itemprop="url" href="#">
               <time itemprop="datePublished" datetime="" class="posted">16u</time>
               <h5 itemprop="name">Vlaamse overheid is werkgever van het jaar</h5>  
          </a>
          </div>

          <div itemscope="" itemtype="http://schema.org/Article" class="field full rss">
            <a itemprop="url" href="#">
                  <time itemprop="datePublished" datetime="" class="posted">16u</time>
                  <h5 itemprop="name">De stemmen zijn geteld</h5> 
              </a>
          </div>
   
          <div itemscope="" itemtype="http://schema.org/Article" class="field full rss">
            <a itemprop="url" href="#">
                  <time itemprop="datePublished" datetime="" class="posted">14u</time>
                  <h5 itemprop="name">Huurpremie na 4 jaar wachten op sociale woning</h5> 
              </a>
          </div>

          <div itemscope="" itemtype="http://schema.org/Article" class="field full rss">
             <a itemprop="url" href="#">
                 <time itemprop="datePublished" datetime="" class="posted">14u</time>
                 <h5 itemprop="name">Huurpremie na 4 jaar wachten op sociale woning</h5> 
              </a>
          </div>

          <div itemscope="" itemtype="http://schema.org/Article" class="field full rss">
             <a itemprop="url" href="#">
                 <time itemprop="datePublished" datetime="" class="posted">14u</time>
                 <h5 itemprop="name">Huurpremie na 4 jaar wachten op sociale woning</h5> 
              </a>
          </div>
      
    <div class="field"><a itemprop="url" class="more" href="#">toon alles  &rsaquo;</a></div>
    
    </div>


<!-- end nieuwsfeed  -->