
<ul itemscope itemtype="http://schema.org/BreadcrumbList" class="breadcrumbs">
  <li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem"><a itemprop="item" href="#">Home</a><meta itemprop="position" content="1" /></li>
  <li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem"><a itemprop="item" href="#">niveau 1</a><meta itemprop="position" content="2" /></li>
  <li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem" class="unavailable"><a itemprop="item" href="#">niveau 2 niet actief</a><meta itemprop="position" content="3" /></li>
  <li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem" class="current"><a itemprop="item" href="#">Actief</a><meta itemprop="position" content="4" /></li>
</ul>


