{% extends "pyoes/layout.jinja2" %}
{% set service_nav =  [
    ('home', 'Styleguide', '/')
    ]
%}
{% set active_title="inventaris" %}
{% set main_nav = [
    ('home', 'Home', 'inventaris'), 
    ('bouwkundig', 'Bouwkundig', '#'), 
    ('landschappelijk', 'Landschappelijk', '#'), 
    ('varend', 'Varend', '#'), 
    ('wereldoorlog', 'Wereldoorlog', '#'), 
    ('faq', 'FAQ', '#'), 
]-%}