
<!-- navigation type 1 -->

<nav class="top-bar" data-topbar role="navigation">
  <ul class="title-area">
    <li class="name">
    </li>
    <li class="toggle-topbar menu-icon"><a href="#"><span>menu</span></a></li>
  </ul>

  <section class="top-bar-section inner-nav">
    <ul>
      <li class="active"><a href="/">Home</a></li>
      <li><a href="">test link 1</a></li>
      <li><a href="">test link 2</a></li>
      <li><a href="">test link 3</a></li>
    </ul>
  </section>
</nav>
