
<!-- social buttons on page -->

<ul class="socialbox dropdown right clearfix">
    <li class="facebook"><a href="#"><i class="fa fa-facebook-square"></i> Facebook</a></li>
    <li class="twitter"><a href="#"><i class="fa fa-twitter"></i> Twitter</a></li>
	<li class="mail"><a href="#"><i class="fa fa-envelope"></i> Mailen</a></li>
    <li class="print"><a href="#"><i class="fa fa-print"></i> Printen</a></li>
</ul>
