
<!-- search 3 extended -->


    <div class="large-12 columns">
        <div class="panel fl-block-search">

       <h3>Uitgebreid Zoeken</h3>

        <form name="" action="#" method="post" class="clearfix">


              <div class="row">
                 <div class="large-4 medium-4 columns">
                      <select>
                        <option value="">filter op</option>
                        <option value="">1</option>
                        <option value="">2</option>
                        <option value="">3</option>
                        <option value="">4</option>
                      </select>
              </div>

              <div class="large-8 medium-8 columns">

              <div class="searchBox">
            		   <input type='text' placeholder='zoek foto' />
            		   <button>toepassen</button>
            		   </div>
                </div>
             </div>

            <ul class="tag-label clearfix">
              <li>Jouw selectie</li>
              <li><a href="#">Fotograaf / <strong>iPhone</strong></a> <a href="#"><span>&#10006;</span></a></li>
              <li><a href="#">Fotograaf / <strong>iPhone</strong></a> <a href="#"><span>&#10006;</span></a></li>
              <li><a href="#">Alle filters verwijderen <span>&#10006;</span></a></li>
            </ul>
            <hr>

        </form>


        <div class="row">

               <div class="large-8 medium-8 columns">
              		<h5>Er zijn geen resultaten beschikbaar</h5>
               </div>

              <div class="large-4 medium-4 columns">
                  <select>
                  <option value="">sorteer op</option>
                  <option value="">datum/aflopend</option>
                  <option value="">datum/oplopend</option>
                  <option value="">titel/aflopend</option>
                  <option value="">titel/oplopend</option>
                  </select>
              </div>

        </div>


       </div>
    </div>

<!-- end search 3 extended-->